*======================================================================*
* FIGURE 3: Life expectancy south and north of the Huai River boundary
*======================================================================*

//Settings
clear all
set type double
set more off 
tempfile t1 t2 t3 t4 t5 
set scheme s1mono

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"


//CODE
use "`IN'/RD_data_merged.dta", clear
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100"  


* Leaves us with 154 observations out of 161.
keep if r03_pm10 != .



* get predicted and residual life expectancy	
reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals


drop longitude* latitude*
gen latitude  = dist_avi1
gen latitude2 = dist_avi2
gen latitude3 = dist_avi3

gen e_0=ex
drop if e_0>95

reg r03_pm10 latitude latitude2 latitude3 north_dist1 north_dist2 north_dist3 north_avi [w=population]
predict pm10_latpred

reg e_0     latitude latitude2 latitude3 north_dist1 north_dist2 north_dist3 north_avi [w=population]
predict le_latpred 

reg pred_ex latitude latitude2 latitude3 north_dist1 north_dist2 north_dist3 north_avi [w=population]
predict pred_le_latpred

reg r03_so2 latitude latitude2 latitude3 north_dist1 north_dist2 north_dist3 north_avi [w=population]
predict so2_latpred

reg r03_no2 latitude latitude2 latitude3 north_dist1 north_dist2 north_dist3 north_avi [w=population]
predict no2_latpred

sum latitude
tab latitude

gen lat_group=.
replace lat_group=-13 if latitude < -12
replace lat_group=-12 if latitude > -12 & latitude < -11
replace lat_group=-11 if latitude > -11 & latitude < -10
replace lat_group=-10 if latitude > -10 & latitude < -9
replace lat_group=-9 if latitude > -9 & latitude < -8
replace lat_group=-8 if latitude > -8 & latitude < -7
replace lat_group=-7 if latitude > -7 & latitude < -6
replace lat_group=-6 if latitude > -6 & latitude < -5
replace lat_group=-5 if latitude > -5 & latitude < -4
replace lat_group=-4 if latitude > -4 & latitude < -3
replace lat_group=-3 if latitude > -3 & latitude < -2
replace lat_group=-2 if latitude > -2 & latitude < -1
replace lat_group=-1 if latitude > -1 & latitude < 0
replace lat_group=1 if latitude > 0 & latitude < 1
replace lat_group=2 if latitude > 1 & latitude < 2
replace lat_group=3 if latitude > 2 & latitude < 3
replace lat_group=4 if latitude > 3 & latitude < 4
replace lat_group=5 if latitude > 4 & latitude < 5
replace lat_group=6 if latitude > 5 & latitude < 6
replace lat_group=7 if latitude > 6 & latitude < 7
replace lat_group=8 if latitude > 7 & latitude < 8
replace lat_group=9 if latitude > 8 & latitude < 9
replace lat_group=10 if latitude > 9 & latitude < 10
replace lat_group=11 if latitude > 10 & latitude < 11
replace lat_group=12 if latitude > 11 & latitude < 12
replace lat_group=13 if latitude > 12 & latitude < 13
replace lat_group=14 if latitude > 13 & latitude < 14
replace lat_group=15 if latitude > 14 & latitude < 15
replace lat_group=16 if latitude > 15 & latitude < 16
replace lat_group=17 if latitude > 16

tab lat_group

gen uno=1
bysort lat_group: egen totalpop_sum=sum(population)
save `t1', replace

collapse (mean) r03_pm10 r03_so2 r03_no2 e_0 pred_ex north_avi pm10_latpred le_latpred pred_le_latpred (sum) uno [w=population], by(lat_group)
tab uno
tsset lat_group
tsfill
drop if lat_group==0 //Created as consequence of tsfill
gen extra=1 //indicator for these lat group obs which will be appended to 154 obs
tab lat_group
tab uno

gen latitude=.
replace latitude=-12.5 if lat_group==-13
replace latitude=-11.5 if lat_group==-12
replace latitude=-10.5 if lat_group==-11
replace latitude=-9.5 if lat_group==-10
replace latitude=-8.5 if lat_group==-9
replace latitude=-7.5 if lat_group==-8
replace latitude=-6.5 if lat_group==-7
replace latitude=-5.5 if lat_group==-6
replace latitude=-4.5 if lat_group==-5
replace latitude=-3.5 if lat_group==-4
replace latitude=-2.5 if lat_group==-3
replace latitude=-1.5 if lat_group==-2
replace latitude=-0.5 if lat_group==-1
replace latitude=0.5 if lat_group==1
replace latitude=1.5 if lat_group==2
replace latitude=2.5 if lat_group==3
replace latitude=3.5 if lat_group==4
replace latitude=4.5 if lat_group==5
replace latitude=5.5 if lat_group==6
replace latitude=6.5 if lat_group==7
replace latitude=7.5 if lat_group==8
replace latitude=8.5 if lat_group==9
replace latitude=9.5 if lat_group==10
replace latitude=10.5 if lat_group==11
replace latitude=11.5 if lat_group==12
replace latitude=12.5 if lat_group==13
replace latitude=13.5 if lat_group==14
replace latitude=14.5 if lat_group==15
replace latitude=15.5 if lat_group==16
replace latitude=16.5 if lat_group==17
summ

append using `t1'
replace extra=0 if extra==.
tab extra
count if totalpop_sum==.
bysort lat_group: egen mtotalpop=mean(totalpop_sum)



*** Figure 3 Local linear RD
lpoly e_0 lat_dist_avi if north_avi==1, degree(1) kernel(tri) bwidth(5.864) gen(le_grid_north le_lpoly_north)
lpoly e_0 lat_dist_avi if north_avi==0, degree(1) kernel(tri) bwidth(5.864) gen(le_grid_south le_lpoly_south)
scatter e_0 latitude [aw=mtotalpop] if extra==1 & north_avi==0, sort mcolor(blue) msize(medium) mfcolor(white) xlabel(-20(5)20)  ylabel(70(5)85, nogrid) || scatter e_0 latitude [aw=mtotalpop] if extra==1 & north_avi==1, sort mcolor(green) msize(medium) mfcolor(white) msymbol(circle) ||line le_lpoly_north le_grid_north , lwidth(1) sort lcolor(gray) msymbol(circle) msize(large) || line le_lpoly_south le_grid_south , xline(0,lcolor(black)) lwidth(1) sort lcolor(gray) msize(large) msymbol(circle) xtitle({bf:Degrees North of the Huai River Boundary}, size(large) height(5)) ytitle({bf:Life Expectancy(Years)}, size(large) height(8)) ///
graphregion(fcolor(255 255 255)) graphregion(lcolor(255 255 255))  legend(rows(1) size(medium) order(1 "L.E. in South" 2 "L.E. in North" 3 "Local Linear Regression") symxsize(small))
graph export "`OUT'/figure3_lpoly.pdf", replace 

gen threshold = 0 in 1
lpoly e_0 lat_dist_avi if north_avi==1, degree(1) kernel(tri) bwidth(5.864) gen(e_0_north_limit) at(threshold)
lpoly e_0 lat_dist_avi if north_avi==0, degree(1) kernel(tri) bwidth(5.864) gen(e_0_south_limit) at(threshold)

gen dif_e_0 = e_0_north_limit - e_0_south_limit
sum e_0_north_limit e_0_south_limit dif_e_0 in 1
