*======================================================================*
* FIGURE S2: Instrumental variables estimates of the impact of an additional 10 
* mg/m3 exposure to PM10 on cardiorespiratory and all cause mortality by age group
*======================================================================*


#delimit ;
 global path       /Users/`c(username)'/Desktop/Huai_River_Replication_Files ; 
 global pathgraph  /Users/`c(username)'/Desktop/Huai_River_Replication_Files/Do_Files/Results ; 


cd $pathgraph ; 
 
clear ;  clear matrix ; clear mata ; 
set matsize 5000 ;  set maxvar 5000 ;   set more off;   set rmsg on ;  pause on;  


matrix A=J(19,4,.) ; 
matrix A[01,1]=0 ; 
matrix A[02,1]=1 ; 
matrix A[03,1]=05 ; 
matrix A[04,1]=10 ; 
matrix A[05,1]=15 ; 
matrix A[06,1]=20 ; 
matrix A[07,1]=25 ; 
matrix A[08,1]=30 ; 
matrix A[09,1]=35 ; 
matrix A[10,1]=40 ; 
matrix A[11,1]=45 ; 
matrix A[12,1]=50 ; 
matrix A[13,1]=55 ; 
matrix A[14,1]=60 ; 
matrix A[15,1]=65 ; 
matrix A[16,1]=70 ; 
matrix A[17,1]=75 ; 
matrix A[18,1]=80 ; 
matrix A[19,1]=85 ; 


***** Cardiorespiratory by-age group results ***** ;
	use $path/Data_Files/RD_data_merged.dta, clear ;     

	keep if r03_pm10 != . ;  
	replace r03_pm10 = r03_pm10/10;
	local outcome  "l_dr4 l_dr4_1 l_dr4_5 l_dr4_10 l_dr4_15 l_dr4_20 l_dr4_25 l_dr4_30 l_dr4_35 l_dr4_40 l_dr4_45 l_dr4_50 l_dr4_55 l_dr4_60 l_dr4_65 l_dr4_70 l_dr4_75 l_dr4_80 l_dr4_85"; 
	local i=1;
	foreach y of local outcome { ; 
		rdrobust `y' lat_dist_avi_revised, kernel(tri) bwselect(IK) all fuzzy(r03_pm10); 
		matrix X=e(tau_F_cl) ; matrix A[`i',2]=X[1,1] ; 
		matrix X=e(se_F_cl)  ; matrix A[`i',3]=X[1,1] ; 
		matrix X= e(pv_F_cl) ; matrix A[`i',4]=X[1,1] ; 
		local ++i ; 
	} ; 
	
	clear ; 
	matrix colnames A = age coef se pvalue; 
	svmat A, names(col) ; 
		
	save est_by_age, replace ; 


	use est_by_age, replace ; 

	#delimit;
	set scheme s1mono;
	replace coef=coef;
	gen b_iv_upper_1=coef+1.96*se;
	gen b_iv_lower_1=coef-1.96*se;
	gen b_iv=0 ;  
	gen zero=0;
	twoway (rarea b_iv_upper_1 b_iv_lower_1 age if age>=0 , sort fintensity(inten10) blcolor(gs14) bfcolor(gs14)) 
	(line zero age if age>=0 & age~=1, sort) 
	(connected coef age if age>=0 & age~=1, sort) , ylabel(, labsize(*1)) xlabel(0(10)80)
	ytitle("IV-RD Estimate of 10{&mu}g/m{superscript:3} of PM{sub:10}" "on Cardiorespiratory Mortality", size(*1)) title() yline(0) xtitle(" ") 
	legend(order(2 "Coefficient Estimates" 1 "95% Confidence Interval") size(small) symx(medium)) ; 
	exit;


***** All-Causes by-age group results ***** ;
	use $path/Data_Files/RD_data_merged.dta, clear ;     

	keep if r03_pm10 != . ;  
	replace r03_pm10 = r03_pm10/10;
	local outcome "l_dr1 l_dr1_1 l_dr1_5 l_dr1_10 l_dr1_15 l_dr1_20 l_dr1_25 l_dr1_30 l_dr1_35 l_dr1_40 l_dr1_45 l_dr1_50 l_dr1_55 l_dr1_60 l_dr1_65 l_dr1_70 l_dr1_75 l_dr1_80 l_dr1_85";
	local i=1;
	foreach y of local outcome { ; 
		rdrobust `y' lat_dist_avi_revised, kernel(tri) bwselect(IK) all fuzzy(r03_pm10); 
		matrix X=e(tau_F_cl) ; matrix A[`i',2]=X[1,1] ; 
		matrix X=e(se_F_cl)  ; matrix A[`i',3]=X[1,1] ; 
		matrix X= e(pv_F_cl) ; matrix A[`i',4]=X[1,1] ; 
		local ++i ; 
	} ; 
	
	clear ; 
	matrix colnames A = age coef se pvalue; 
	svmat A, names(col) ; 
		
	save est_by_age, replace ; 


	use est_by_age, replace ; 

	#delimit;
	set scheme s1mono;
	replace coef=coef;
	gen b_iv_upper_1=coef+1.96*se;
	gen b_iv_lower_1=coef-1.96*se;
	gen b_iv=0 ;  
	gen zero=0;
	twoway (rarea b_iv_upper_1 b_iv_lower_1 age if age>=0 , sort fintensity(inten10) blcolor(gs14) bfcolor(gs14)) 
	(line zero age if age>=0 & age~=1, sort) 
	(connected coef age if age>=0 & age~=1, sort) , ylabel(, labsize(*1)) xlabel(0(10)80)
	ytitle("IV-RD Estimate of 10{&mu}g/m{superscript:3} of PM{sub:10}" "on All Cause Mortality", size(*1)) title() yline(0) xtitle(" ") 
	legend(order(2 "Coefficient Estimates" 1 "95% Confidence Interval") size(small) symx(medium)) ; 
	exit;







