*======================================================================*
* Figure S3: Placebo testing: Estimated discontinuity in pollution and 
* life expectancy at displaced Huai River boundaries using the 
* bandwidth selection method proposed by Calonico et al (2014a)	
*======================================================================*

clear all
//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 
set scheme s1mono

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local OUTPUT $root/Do_files/Results
local IN $root/Data_Files/


//CODE
*****************
forvalues i=-5(1)5{
	use "`IN'/RD_data_merged.dta", clear
	keep if r03_pm10 != .
	rdrobust ex lat_dist_avi_revised,c(`i') kernel(tri) bwselect(CCT)
	gen b_lwald=e(tau_cl)
	gen se_lwald=e(se_cl)
	keep b_lwald se_lwald
	gen z=`i'
	keep in 1
	save "`OUTPUT'/temp_`i'.dta",replace
	}

clear
set obs 1
forvalues i=-5(1)5{
	append using "`OUTPUT'/temp_`i'.dta"
	}

gen b_upper_ex=b_lwald+1.96*se_lwald
gen b_lower_ex=b_lwald-1.96*se_lwald
rename b_lwald b_lwald_ex
sort z
save `t1',replace

forvalues i=-5(1)5{
	use "`IN'/RD_data_merged.dta", clear
	keep if r03_pm10 != .
	rdrobust r03_pm10 lat_dist_avi_revised,c(`i') kernel(tri) bwselect(CCT)
	gen b_lwald=e(tau_cl)
	gen se_lwald=e(se_cl)
	keep b_lwald se_lwald
	gen z=`i'
	keep in 1
	save "`OUTPUT'/temp_`i'.dta",replace
	}

clear
set obs 1
forvalues i=-5(1)5{
	append using "`OUTPUT'/temp_`i'.dta"
	}

gen b_upper_pol=b_lwald+1.96*se_lwald
gen b_lower_pol=b_lwald-1.96*se_lwald
rename b_lwald b_lwald_pol

sort z
append using `t1'

gen zero=0
#delimit;
local cube = char(179);

twoway (rcap b_upper_pol b_lower_pol z if z>=-5.2 & z<=5.2, sort fintensity(inten10)  blcolor(red) bfcolor(red)  ) (line zero z if z>=-5.2 & z<=5.2, sort) (scatter b_lwald_pol z if z>=-5.2 & z<=5.2, sort msym(Oh) mcolor(red) msize(*1.2) yaxis(1)) (rcap b_upper_ex b_lower_ex z if z>=-5.2 & z<=5.2, sort fintensity(inten10)  blcolor(blue) bfcolor(blue) yaxis(2)) (scatter b_lwald_ex z if z>=-5.2 & z<=5.2, sort msym(Oh) mcolor(blue) msize(*1.2) yaxis(2)) , xlabel(-5(1)5) ylabel(-12(3)12, labsize(*.8)axis(2))  ylabel(-120(30)120, labsize(*.8)axis(1))  ytitle({bf:PM10({&mu}g/m{superscript:3})},size(*1.2)axis(1)) ytitle({bf:Years of Life Expectancy},size(*1.2)axis(2)) ysc(titlegap(3)axis(1)) ysc(titlegap(3)axis(2)) title() yline(0,axis(1))  xtitle(" ") legend(order(3 "Coeff Estimate on PM{sub:10}" 5 "Coeff Estimate on Life Expectancy" 1 "95% Confidence Interval" 4 "95% Confidence Interval") size(small) symx(medium) rows(2));
#delimit cr

graph export "`OUTPUT'/figureS3.pdf", replace
forvalues i=-5(1)5{
	cap erase "`OUTPUT'/temp_`i'.dta"
	}
