*======================================================================*
* TABLES 1 AND S1: Summary statistics								   *
*======================================================================*

clear
set more off 

global path     /Users/`c(username)'/Desktop/Huai_River_Replication_Files
global result   /Users/`c(username)'/Desktop/Huai_River_Replication_Files/Do_Files/Results

*****  Regression Results ***** 

use $path/Data_Files/RD_data_merged.dta, clear

keep if r03_pm10 != .

local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100  medservice r2003_Level"  

reg ex `OLS_var' [w=population], robust

predict pred_ex
predict resid_ex, residuals

matrix joint_test = (1,1)

***** Table 1 Summary Statistics *****

	cap erase $result/T1_simple_diff.txt
	cap erase $result/T1_simple_diff.xml
	cap erase $result/T1_poly_diff.txt
	cap erase $result/T1_poly_diff.xml
	cap erase $result/T1_local_diff.txt
	cap erase $result/T1_local_diff.xml
	
	** Columns 1 and 2
	
	local All_var "r03_pm10 r03_so2 r03_no2 r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare  dist_dum100 smkexp bdrk redmeat inspa ex ex5 ex60 l_ajdr4 l_ajdr10 l_ajdr11 pred_ex resid_ex medservice r2003_Level"
	sum `All_var' ajdr4 ajdr10 ajdr11 [w=population] if north_avi == 1, sep(0)
	sum `All_var' ajdr4 ajdr10 ajdr11 [w=population] if north_avi == 0, sep(0)
	
		**North Summary Stats
		putexcel set $result/Table1.xls, sheet(Col_1_2_north, replace) modify 
		putexcel A1=("Var Name") B1=("Mean") C1=("SD")
		local i = 2
		foreach v of var `All_var' {
			sum `v' [w=population] if north_avi == 1, sep(0) 
			putexcel A`i'=("`v'") B`i' = ("`r(mean)'") C`i'=("`r(sd)'")
			local i = `i'+1
		}
	
		**South Summary Stats
		putexcel set $result/Table1.xls, sheet(Col_1_2_south, replace) modify 
		putexcel A1=("Var Name") B1=("Mean") C1=("SD")
		local i = 2
		foreach v of var `All_var' {
			sum `v' [w=population] if north_avi == 0, sep(0) 
			putexcel A`i'=("`v'") B`i' = ("`r(mean)'") C`i'=("`r(sd)'")
			local i = `i'+1
		}
		
	** Columns 3: simple difference
	foreach y of var `All_var' { 
		local d  = 2
		if "`y'"== "r03_pm10" | "`y'"== "r03_so2" | "`y'"== "r03_no2" | "`y'"== "r04_heating_degrees" | "`y'"== "r04_cooling_degrees" | "`y'"== "rainfall" | "`y'"== "pcincome" | "`y'"== "minoshare" | "`y'"== "redmeat"  | "`y'"== "inspa" |  "`y'"== "r2003_Level" |  "`y'"== "pred_ex"{
			local d = 1
		}
		
		reg `y' north_avi [w=population], robust
		outreg2 using $result/T1_simple_diff, excel stats(coef se pval) ctitle(`y') dec(`d') append 
		}
	
		**Joint test of significance
		foreach y of var `All_var' { 
			reg `y' north_avi [w=population]
			est store `y'
			}
		suest `All_var', robust
		
		**Using covariates from Panel B
		test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi 
		matrix joint_test = (joint_test \ r(chi2), r(p))
		
		**Using covariates from Panel C and D
		test [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi 
		matrix joint_test = (joint_test \ r(chi2), r(p))

		**Using covariates from Panel B and C and D
		test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi 
		matrix joint_test = (joint_test \ r(chi2), r(p))

		**Using only non-significant covariates
		test [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi
		matrix joint_test = (joint_test \ r(chi2), r(p))
		
	** Columns 4: 3rd order polynomial adjusted difference
	local All_var "r03_pm10 r03_so2 r03_no2 r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare  dist_dum100 smkexp bdrk redmeat inspa ex ex5 ex60 l_ajdr4 l_ajdr10 l_ajdr11 pred_ex resid_ex medservice r2003_Level"

	foreach y of var `All_var' { 
		local d  = 2
		if "`y'"== "r03_pm10" | "`y'"== "r03_so2" | "`y'"== "r03_no2" | "`y'"== "r04_heating_degrees" | "`y'"== "r04_cooling_degrees" | "`y'"== "rainfall" | "`y'"== "pcincome" | "`y'"== "minoshare" | "`y'"== "bdrk"  | "`y'"== "inspa" |  "`y'"== "pred_ex"{
			local d = 1
		}
		reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
		outreg2 using $result/T1_poly_diff, excel stats(coef se pval) dec(`d') append
	}
	
		**Joint test of significance
		foreach y of var `All_var' { 
			qui reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population]
			est store `y'
			}
		suest `All_var', robust
		
		**Using covariates from Panel B
		test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi 
		matrix joint_test = (joint_test \ r(chi2), r(p))

		**Using covariates from Panel C and d
		test [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi
		matrix joint_test = (joint_test \ r(chi2), r(p))

		**Using covariates from Panel B and C and D
		test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi
		matrix joint_test = (joint_test \ r(chi2), r(p))

		**Using only non-significant covariates
		test [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [r2003_Level_mean]north_avi
		matrix joint_test = (joint_test \ r(chi2), r(p))


		
		
	** Columns 5: local linear regression adjusted difference
	foreach y of var `All_var' {
		local d  = 2
		if "`y'"== "r03_pm10" | "`y'"== "r03_so2" | "`y'"== "r03_no2" | "`y'"== "r04_heating_degrees" | "`y'"== "r04_cooling_degrees" | "`y'"== "rainfall" | "`y'"== "pcincome" | "`y'"== "minoshare" | "`y'"== "redmeat" | "`y'"== "smkexp" | "`y'"== "bdrk"  | "`y'"== "inspa" | "`y'"== "r2003_Level" |   "`y'"== "pred_ex"{
			local d = 1
		}
		rdrobust `y' lat_dist_avi_revised,  kernel(tri) bwselect(IK) all
		outreg2 using $result/T1_local_diff, excel ctitle(`y') addstat(Robust Std. Err., e(se_rb)) dec(`d') append 
	}
	
	
		**Joint test of significance
		matrix bandwidths = (1)
		foreach y of var `All_var' {
			 rdrobust `y' lat_dist_avi_revised, kernel(uni) bwselect(IK)
			matrix bandwidths = (bandwidths \ e(h_bw))
		}
		
		local i = 2
		**Joint test of significance
			foreach y of var `All_var' { 
				qui reg `y' north_avi dist_avi1 north_dist1 if dist_avi1 < bandwidths[`i',1] & dist_avi1 > -bandwidths[`i',1]
				est store `y'
				local i = `i' + 1
				}
			suest `All_var', robust
		
	**Using covariates from Panel C and D
	test [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi  [medservice_mean]north_avi [r2003_Level_mean]north_avi 
	matrix joint_test = (joint_test \ r(chi2), r(p))
		
		
	**Using covariates from Panel B and C and D
	test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi  [medservice_mean]north_avi [r2003_Level_mean]north_avi 
	matrix joint_test = (joint_test \ r(chi2), r(p))	
	
	
	matrix rownames joint_test = "NA" "Simple Panel B" "Simple Panel C" "Simple Panel B + C" "Simple Non-Sig" "Poly Panel B" "Poly Panel C" "Poly Panel B + C" "Poly Non-Sig" "Local Linear Panel B" "Local Linear Panel C" 
	matrix colnames joint_test = "Chi2" "Pvalue"

	putexcel set $result/Table1.xls, sheet(joint, replace)  modify
	putexcel A1 = matrix(joint_test), names nformat(number_d2)

	*** Output Table 1 **
	xmluse $result/T1_simple_diff.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table1, sheet("T1_simple_diff", replace) 
	
	xmluse $result/T1_poly_diff.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table1, sheet("T1_poly_diff", replace) 
	
	xmluse $result/T1_local_diff.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear
	export excel using $result/Table1, sheet("T1_local_diff", replace) 

