*======================================================================*
* TABLES 2, 3, S7, S8, S10 AND S11: 
* Main regression discontinuity estimates of the impact of the Huai River
* on pollution and health 
*======================================================================*
clear
set more off 

global path    /Users/`c(username)'/Desktop/Huai_River_Replication_Files
global result   /Users/`c(username)'/Desktop/Huai_River_Replication_Files/Do_Files/Results

*****  Regression Results ***** 

use $path/Data_Files/RD_data_merged, clear

keep if r03_pm10 != .

local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  

reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals

***** Table 2. RD Results *****
	*=====
	*** Maoyong save a dta file for RD graphs 
	**saveold $path\graphs.dta, replace
	*=====
	
	
	cap erase $result/T2_poly_RD.txt
	cap erase $result/T2_poly_RD.xml
	cap erase $result/T2_linear_RD.txt
	cap erase $result/T2_linear_RD.xml	
	
	** Columns 1-4
	* r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2
	
	local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2" 
	
	foreach y of local outcome {
		reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
		if "`y'"== "r03_pm10" |  "`y'"== "ex"{
			outreg2 using $result/T2_poly_RD, excel dec(1) append
		}
		else{
		outreg2 using $result/T2_poly_RD, excel dec(2) append
		}
		* Maoyong add results with controls 
		reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
		if "`y'"== "r03_pm10" |  "`y'"== "ex"{
			outreg2 using $result/T2_poly_RD, excel dec(1) append
		}
		else{
			outreg2 using $result/T2_poly_RD, excel dec(2) append
		}

		reg `y' north_avi dist_avi1 north_dist1 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
		if "`y'"== "r03_pm10" |  "`y'"== "ex"{
			outreg2 using $result/T2_linear_RD , excel dec(1) append 
		}
		else{
			outreg2 using $result/T2_linear_RD , excel dec(2) append 
		}
		* Maoyong add results with controls 
		reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust 
		if "`y'"== "r03_pm10" |  "`y'"== "ex"{
			outreg2 using $result/T2_linear_RD , excel dec(1) append 
		}
		else{
			outreg2 using $result/T2_linear_RD , excel dec(2) append 
		}
	}
	

	** Columns 5-7
	local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2" 
	local kernelfn "tri epa uni"  
	local bwmethod "CCT IK CV" 
	
	foreach y of local outcome { 
		cap erase $result/T2_RD_`y'.txt 
		cap erase $result/T2_RD_`y'.xml 
		cap erase $result/T2_FzRD_`y'.txt 
		cap erase $result/T2_FzRD_`y'.xml 		
	} 	
	
	* Authomatic bandwidth models: 

	foreach y of local outcome { 
	
		foreach bvar of local bwmethod { 
			local i=1   
			foreach kvar of local kernelfn { 
	
					rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(`bvar') all 					
						outreg2 using $result/T2_RD_`y', excel 	addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`dvar') dec(2) append 
					
					if "`y'"=="ex" & "`e(bwsel)'"=="CCT" { 
						local b`i'=`e(h_bw)' 
						local ++i  
					}  
	 			}  	
			
			}
		} 			
	
	* Manually choose bandwidth: 5 degrees
	foreach y of local outcome { 
	  
			foreach kvar of local kernelfn { 
	
					rdrobust `y' lat_dist_avi_revised, kernel(`kvar') h(5) all 
					* set bandwidth to 5 degrees
						outreg2 using $result/T2_RD_`y', excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`dvar') dec(1) append 
			}
		} 



	foreach y of local outcome { 
	  	local i=1
			foreach kvar of local kernelfn { 
	
					rdrobust `y' lat_dist_avi_revised, kernel(`kvar') h(`b`i'') all 
						outreg2 using $result/T2_RD_`y', excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`dvar') dec(1) append 
					local ++i 
			}
		} 



* fuzzy local linear 

	local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex" 
	replace r03_pm10=r03_pm10/10 

	* Authomatic bandwidth models: 
	foreach y of local outcome { 
	
		foreach bvar of local bwmethod { 
	  
			foreach kvar of local kernelfn { 
	
					rdrobust `y' lat_dist_avi_revised,  fuzzy(r03_pm10) kernel(`kvar') bwselect(`bvar') all 
					
						outreg2 using $result/T2_FzRD_`y', excel 	addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  ctitle(`dvar')  dec(2) append 
	 			}  	
			
			}
		} 			
	
	* Manually choose bandwidth: 5 degrees
	foreach y of local outcome { 
	  
			foreach kvar of local kernelfn { 
	
					rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10) kernel(`kvar') h(5) all 
					* set bandwidth to 5 degrees
						outreg2 using $result/T2_FzRD_`y', excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')   ctitle(`dvar') dec(2) append 
			}
		} 

*/
	*** Output Table 2 ***
	xmluse $result/T2_poly_RD.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_poly_RD", replace) 
	
	xmluse $result/T2_linear_RD.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_linear_RD", replace) 
	

	xmluse $result/T2_RD_r03_pm10.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_PM10", replace) 
	
	xmluse $result/T2_RD_ex.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_ex", replace) 
	
	xmluse $result/T2_RD_ex5.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_ex5", replace) 
	
	xmluse $result/T2_RD_ex60.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_ex60", replace) 
	
	xmluse $result/T2_RD_l_ajdr4.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_l_ajdr4", replace) 
	
	xmluse $result/T2_RD_resid_ex.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_resid_ex", replace) 
	
	xmluse $result/T2_RD_l_ajdr10.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_l_ajdr10", replace) 
	
	xmluse $result/T2_RD_l_ajdr11.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_l_ajdr11", replace) 
	
	xmluse $result/T2_RD_pred_ex.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_pred_ex", replace) 
	
	xmluse $result/T2_RD_r03_no2.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_RD_no2", replace) 
	
	xmluse $result/T2_FzRD_ex.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_ex", replace) 
	
	xmluse $result/T2_FzRD_ex5.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_ex5", replace) 
	
	xmluse $result/T2_FzRD_ex60.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_ex60", replace) 
	
	xmluse $result/T2_FzRD_l_ajdr4.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_l_ajdr4", replace) 
	
	xmluse $result/T2_FzRD_resid_ex.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_resid_ex", replace) 
	
	xmluse $result/T2_FzRD_l_ajdr10.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_l_ajdr10", replace) 
	
	xmluse $result/T2_FzRD_l_ajdr11.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_l_ajdr11", replace) 
	
	xmluse $result/T2_FzRD_pred_ex.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table2, sheet("T2_FzRD_pred_ex", replace) 


***** Table 3 Comparing OLS and Regression Discontinuity Estimates of Particulate Matter's Impact on Health Outcomes

	** Columns 1 and 2 
	use $path/Data_Files/RD_data_merged, clear
	keep if r03_pm10 != .
	
	local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100  medservice r2003_Level"  
	
	reg ex `OLS_var' [w=population], robust
	predict pred_ex
	predict resid_ex, residuals

	cap erase $result/T3_conventional.txt 
	cap erase $result/T3_conventional.xml 
	cap erase $result/T3_IV.txt 
	cap erase $result/T3_IV.xml 
	
	replace r03_pm10 = r03_pm10/10           
	/* Table 3 must note that this is the effect of 10 mg/m3 pm10 NOT 1mg/m3 */  
	
	foreach y of var ex ex5 ex60 l_ajdr4 {
	reg `y' r03_pm10 [w=population], robust
	outreg2 using $result/T3_conventional, excel dec(2) adds(F-stat, e(F)) append
	reg `y' r03_pm10 `OLS_var' [w=population], robust
	outreg2 using $result/T3_conventional, excel dec(2)  adds(F-stat, e(F)) append
	reg `y' r03_pm10 [w=population]  if dist_avi1>=-5 & dist_avi1<=5, robust
	outreg2 using $result/T3_conventional, excel dec(2)  adds(F-stat, e(F)) append
	reg `y' r03_pm10 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5, robust
	outreg2 using $result/T3_conventional, excel dec(2)  adds(F-stat, e(F)) append
	} 
	
	foreach y of var ex ex5 ex60 l_ajdr4 { 
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 (r03_pm10 = north_avi) [w=population]
	outreg2 using $result/T3_IV, excel dec(2)  adds(Chi-squared, e(chi2)) append
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' (r03_pm10 = north_avi) [w=population]
	outreg2 using $result/T3_IV, excel dec(2)  adds(Chi-squared, e(chi2)) append
	ivregress 2sls `y' dist_avi1 north_dist1 (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5
	outreg2 using $result/T3_IV, excel dec(2)  adds(Chi-squared, e(chi2)) append
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5
	outreg2 using $result/T3_IV, excel dec(2)  adds(Chi-squared, e(chi2)) append
	
	}
	



***** Fuzzy RD results (IV Estimates) 
	local outcome "ex ex5 ex60 l_ajdr4" 
	local kernelfn "tri epa uni"  
	
	foreach  y of local outcome { 
		cap erase $result/T3_Fuzzy_RD.txt 
		cap erase $result/T3_Fuzzy_RD.xml 
	} 	
	
	* Authomatic bandwidth models: 
	foreach y of local outcome { 
	
			foreach kvar of local kernelfn { 
	
					rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10) bwselect(IK) kernel(`kvar') all 
					
						outreg2 using $result/T3_Fuzzy_RD, excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)') ctitle(`y') dec(2) append 
	 			}  	
			
		} 			
	

				
						
	
	***** Output Table 3 *****
	
	xmluse $result/T3_conventional, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table3, sheet("T3_conventional", replace) 
	
	xmluse $result/T3_IV, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table3, sheet("T3_IV", replace) 
	
	xmluse $result/T3_Fuzzy_RD, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using $result/Table3, sheet("T3_Fuzzy_RD", replace) 
	


