*======================================================================*
* TABLE S12: Robustness checks using weighted averages of PM10
* across monitoring stations
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"

//Code
cap erase "`OUT'/S12_poly.xml"
cap erase "`OUT'/S12_poly.txt"
cap erase "`OUT'/S12_RD.xml"
cap erase "`OUT'/S12_RD.txt"
cap erase "`OUT'/S12_RD_fixh.xml"
cap erase "`OUT'/S12_RD_fixh.txt"


local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100  medservice r2003_Level"
local OLS_var_1 "smkexp_1 bdrk_1 redmeat_1 inspa_1 r04_heating_degrees_1 r04_cooling_degrees_1 rainfall_1 pcincome_1 v5_yrsed_1 minoshare_1 dist_dum100_1"

local outcome "r03_pm10 ex r04_heating_degrees r04_cooling_degrees rainfall r03_so2 r03_no2"		
local files "regw1_data_04_12_v4_S16 regw2_data_04_12_v4_S16 regw3_data_04_12_v4_S16 regw4_data_04_12_v4_S16 regr10_data_04_12_v4_S16 regr25_data_04_12_v4_S16 regr50_data_04_12_v4_S16 regr75_data_04_12_v4_S16 regr100_data_04_12_v4_S16 regr125_data_04_12_v4_S16 regr150_data_04_12_v4_S16"
		
foreach y of local outcome {
	
	foreach file of local files {
	
		use "`IN'/`file'", clear
		keep if sex == 0
		collapse overall_sequ ex ex5 ex60 ajdr4 ajdr10 ajdr11 pm10 r03_pm10 r03_so2 r03_no2 smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare v1_manufsh north_avi dist_avi_revised dist_coast population  medservice r2003_Level, by (code sex)
		keep if r03_pm10!=.
		replace north_avi = 1 if north_avi == -1
		replace dist_avi_revised = -dist_avi_revised if north_avi == 0
		gen lat_dist_avi_revised = dist_avi_revised/111000
		gen dist_avi1=lat_dist_avi_revised 
		gen dist_avi2=lat_dist_avi_revised^2  
		gen dist_avi3=lat_dist_avi_revised^3  
		gen dist_avi4=lat_dist_avi_revised^4  
		gen dist_avi5=lat_dist_avi_revised^5
		gen north_dist1 = north_avi*dist_avi1
		gen north_dist2 = north_avi*dist_avi2
		gen north_dist3 = north_avi*dist_avi3
		gen north_dist4 = north_avi*dist_avi4
		gen north_dist5 = north_avi*dist_avi5
		replace r04_heating_degrees = r04_heating_degrees/1000
		replace r04_cooling_degrees = r04_cooling_degrees/1000
		replace dist_coast = dist_coast/1000
		gen dist_dum100 = 1 if dist_coast <=100
		replace dist_dum100 = 0 if dist_coast >100
		gen Lpcincome=log(pcincome) 
		replace pcincome = pcincome/1000
		replace minoshare = minoshare*100 						
		reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
		outreg2 using "`OUT'/S12_poly", excel dec(1) ctitle(`y'_`file') append
		}
	}
		
foreach y of local outcome {
	
	foreach file of local files {
	
		use "`IN'/`file'", clear
		keep if r03_pm10!=.
		keep if sex == 0
		collapse ex ex5 ex60 ajdr4 ajdr10 ajdr11 pm10 r03_pm10 r03_so2 r03_no2 smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare v1_manufsh north_avi dist_avi_revised dist_coast population  medservice r2003_Level, by (code)
		keep if r03_pm10!=.
		replace north_avi = 1 if north_avi == -1
		replace dist_avi_revised = -dist_avi_revised if north_avi == 0
		gen lat_dist_avi_revised = dist_avi_revised/111000
		gen dist_avi1=lat_dist_avi_revised 
		gen dist_avi2=lat_dist_avi_revised^2  
		gen dist_avi3=lat_dist_avi_revised^3  
		gen dist_avi4=lat_dist_avi_revised^4  
		gen dist_avi5=lat_dist_avi_revised^5
		gen north_dist1 = north_avi*dist_avi1
		gen north_dist2 = north_avi*dist_avi2
		gen north_dist3 = north_avi*dist_avi3
		gen north_dist4 = north_avi*dist_avi4
		gen north_dist5 = north_avi*dist_avi5
		replace r04_heating_degrees = r04_heating_degrees/1000
		replace r04_cooling_degrees = r04_cooling_degrees/1000
		replace dist_coast = dist_coast/1000
		gen dist_dum100 = 1 if dist_coast <=100
		replace dist_dum100 = 0 if dist_coast >100
		gen Lpcincome=log(pcincome) 
		replace pcincome = pcincome/1000
		replace minoshare = minoshare*100 		
		rdrobust `y' lat_dist_avi_revised, bwselect(IK) all
		outreg2 using "`OUT'/S12_RD", excel ctitle(`y'_`file') addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') addstat(Point Estimate, e(tau_bc), Robust Std. Err., e(se_rb), Robust p-value, e(pv_rb)) dec(1) append 
		
		* need to use the bandwidth of the main specification 
		rdrobust `y' lat_dist_avi_revised,  bwselect(IK) h(9.296906624889715) all
		outreg2 using "`OUT'/S12_RD_fixh", excel ctitle(`y'_`file') addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') addstat(Point Estimate, e(tau_bc), Robust Std. Err., e(se_rb), Robust p-value, e(pv_rb)) dec(1) append 
		
		}
	}

** Output: Table S12 ** 
xmluse "`OUT'/S12_poly.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS12", sheet("S12_poly", replace) 

xmluse "`OUT'/S12_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS12", sheet("S12_RD", replace) 

xmluse "`OUT'/S12_RD_fixh.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS12", sheet("S12_RD_fixh", replace) 


cap erase "`OUT'/S12_poly.xml"
cap erase "`OUT'/S12_poly.txt"
cap erase "`OUT'/S12_RD.xml"
cap erase "`OUT'/S12_RD.txt"
cap erase "`OUT'/S12_RD_fixh.xml"
cap erase "`OUT'/S12_RD_fixh.txt"
