*======================================================================*
* TABLE S13: Robustness checks of choice of acceptable distance from DSP
* locations to monitoring stations
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"


//Code
cap erase "`OUT'/S13_poly.xml"
cap erase "`OUT'/S13_poly.txt"
cap erase "`OUT'/S13_RD.xml"
cap erase "`OUT'/S13_RD.txt"
cap erase "`OUT'/S13_RD_fixh.xml"
cap erase "`OUT'/S13_RD_fixh.txt"

local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex" 
local files "regd400_data_04_12_v4_S16 regd300_data_04_12_v4_S16 regd200_data_04_12_v4_S16 regd150_data_04_12_v4_S16 regd125_data_04_12_v4_S16 regd100_data_04_12_v4_S16 regd75_data_04_12_v4_S16 regd50_data_04_12_v4_S16"
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  


foreach y of local outcome {

	foreach file of local files {
	
		use "`IN'/`file'", clear
		keep if sex == 0
		collapse  ex ex5 ex60 ajdr4 ajdr10 ajdr11 pm10 r03_pm10 r03_so2 r03_no2 smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare v1_manufsh north_avi dist_avi_revised dist_coast population  medservice r2003_Level, by (code)
		gen l_ajdr4= log(1+ajdr4)
		gen l_ajdr10= log(1+ajdr10)
		gen l_ajdr11= log(1+ajdr11)
		replace north_avi = 1 if north_avi == -1
		replace dist_avi_revised = -dist_avi_revised if north_avi == 0
		gen lat_dist_avi_revised = dist_avi_revised/111000
		gen dist_avi1=lat_dist_avi_revised 
		gen dist_avi2=lat_dist_avi_revised^2  
		gen dist_avi3=lat_dist_avi_revised^3  
		gen dist_avi4=lat_dist_avi_revised^4  
		gen dist_avi5=lat_dist_avi_revised^5
		gen north_dist1 = north_avi*dist_avi1
		gen north_dist2 = north_avi*dist_avi2
		gen north_dist3 = north_avi*dist_avi3
		gen north_dist4 = north_avi*dist_avi4
		gen north_dist5 = north_avi*dist_avi5
		replace dist_coast = dist_coast/1000
		gen dist_dum100 = 1 if dist_coast <=100
		replace dist_dum100 = 0 if dist_coast >100
		gen Lpcincome=log(pcincome) 
		replace pcincome = pcincome/1000
		replace minoshare = minoshare*100 					
		keep if r03_pm10 != .
		reg ex `OLS_var' [w=population], robust
		predict pred_ex
		predict resid_ex, residuals


		reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
		outreg2 using "`OUT'/S13_poly", excel ctitle(`y'_`file') dec(1) append
	
		}
	}


foreach y of local outcome {

	foreach file of local files {
	
		use "`IN'/`file'", clear
		keep if sex == 0
		collapse  ex ex5 ex60 ajdr4 ajdr10 ajdr11 pm10 r03_pm10 r03_so2 r03_no2 smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare v1_manufsh north_avi dist_avi_revised dist_coast population medservice r2003_Level, by (code)
		gen l_ajdr4= log(1+ajdr4)
		gen l_ajdr10= log(1+ajdr10)
		gen l_ajdr11= log(1+ajdr11)
		replace north_avi = 1 if north_avi == -1
		replace dist_avi_revised = -dist_avi_revised if north_avi == 0
		gen lat_dist_avi_revised = dist_avi_revised/111000
		gen dist_avi1=lat_dist_avi_revised 
		gen dist_avi2=lat_dist_avi_revised^2  
		gen dist_avi3=lat_dist_avi_revised^3  
		gen dist_avi4=lat_dist_avi_revised^4  
		gen dist_avi5=lat_dist_avi_revised^5
		gen north_dist1 = north_avi*dist_avi1
		gen north_dist2 = north_avi*dist_avi2
		gen north_dist3 = north_avi*dist_avi3
		gen north_dist4 = north_avi*dist_avi4
		gen north_dist5 = north_avi*dist_avi5
		replace dist_coast = dist_coast/1000
		gen dist_dum100 = 1 if dist_coast <=100
		replace dist_dum100 = 0 if dist_coast >100
		gen Lpcincome=log(pcincome) 
		replace pcincome = pcincome/1000
		replace minoshare = minoshare*100 	
					
		keep if r03_pm10 != .
		reg ex `OLS_var' [w=population], robust
		predict pred_ex
		predict resid_ex, residuals
		
		if "`y'"=="ex"{
			rdrobust `y' lat_dist_avi_revised, bwselect(IK) all
			outreg2 using "`OUT'/S13_RD", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`y'_`file') dec(1) append	

			rdrobust `y' lat_dist_avi_revised,  bwselect(IK) h(5.863911849810561) all 
			outreg2 using "`OUT'/S13_RD_fixh", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`y'_`file') dec(1) append
			}
		else {
			rdrobust `y' lat_dist_avi_revised, bwselect(IK) all
			outreg2 using "`OUT'/S13_RD", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`y'_`file') dec(1) append	

			rdrobust `y' lat_dist_avi_revised,  bwselect(IK) h(9.296906624889715) all 
			outreg2 using "`OUT'/S13_RD_fixh", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`y'_`file') dec(1) append			
			}
	
		}

	}

** Output: Table S13 ** 
xmluse "`OUT'/S13_poly.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS13", sheet("S13_poly", replace) 

xmluse "`OUT'/S13_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS13", sheet("S13_RD", replace) 

xmluse "`OUT'/S13_RD_fixh.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS13", sheet("S13_RD_fixh", replace) 


cap erase "`OUT'/S13_poly.xml"
cap erase "`OUT'/S13_poly.txt"
cap erase "`OUT'/S13_RD.xml"
cap erase "`OUT'/S13_RD.txt"
cap erase "`OUT'/S13_RD_fixh.xml"
cap erase "`OUT'/S13_RD_fixh.txt"
