*======================================================================*
* TABLE S14: Regressions discontinuity estimates of the impact of the
* Huai River policy using the full sample
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"


//Code
cap erase "`OUT'/S14_poly_RD.xml"
cap erase "`OUT'/S14_poly_RD.txt"
cap erase "`OUT'/S14_linear_RD.xml"
cap erase "`OUT'/S14_linear_RD.txt"
cap erase "`OUT'/S14_IVpoly_RD.xml"
cap erase "`OUT'/S14_IVpoly_RD.txt"
cap erase "`OUT'/S14_IVlinear_RD.xml"
cap erase "`OUT'/S14_IVlinear_RD.txt"

foreach var in ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2  {
	cap erase "`OUT'/S14_RD_`var'.xml"
	cap erase "`OUT'/S14_RD_`var'.txt"
} 


use "`IN'/RD_data_merged.dta", clear
replace r03_pm10=r03_pm10/10


local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  

reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals

* Using full sample
* keep if r03_pm10 != .

local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11" 
foreach y of local outcome  {
	local d = 2
	if `y'==ex{
		local d = 1
	}
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/S14_poly_RD", excel dec(`d') append

	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/S14_poly_RD", excel dec(`d') append

	reg `y' north_avi dist_avi1 north_dist1 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S14_linear_RD" , excel dec(`d') append 
	
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S14_linear_RD" , excel dec(`d') append 
	}

* 2sls 

foreach y of local outcome  {
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S14_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S14_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 north_dist1 (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S14_IVlinear_RD" , excel dec(2) append 
	
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S14_IVlinear_RD" , excel dec(2) append 
	}




local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2" 
local kernelfn "tri epa uni"  
local bwmethod "IK CCT CV" 

foreach y of local outcome { 
	cap erase "`OUT'/S14_RD_`y'.txt"
	cap erase "`OUT'/S14_RD_`y'.xml" 
	cap erase "`OUT'/S14_FzRD_`y'.txt" 
	cap erase "`OUT'/S14_FzRD_`y'.xml" 	
	} 	

* Authomatic bandwidth models: 
foreach y of local outcome { 

	foreach bvar of local bwmethod { 
  
		foreach kvar of local kernelfn { 

			local d = 2
				if `y'==ex{
				local d = 1
			}
			rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(`bvar') all 
			outreg2 using "`OUT'/S14_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)') ctitle(`dvar') dec(`d') append 
			
			rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10) kernel(`kvar') bwselect(`bvar') all 
			outreg2 using "`OUT'/S14_FzRD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)') ctitle(`y') dec(2) append 
					
 			}  	
		}
	} 			

* Manually choose bandwidth: 5 degrees
foreach y of local outcome { 
  
	foreach kvar of local kernelfn { 

		rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(IK) h(5) all 
		outreg2 using "`OUT'/S14_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)') ctitle(`dvar') dec(2) append 
		
		}
	} 
	
	
** output Table S14 ** 
xmluse "`OUT'/S14_poly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS14", sheet("S14_poly_RD", replace) 

xmluse "`OUT'/S14_linear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS14", sheet("S14_linear_RD", replace) 

xmluse "`OUT'/S14_IVpoly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS14", sheet("S14_IVpoly_RD", replace) 

xmluse "`OUT'/S14_IVlinear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS14", sheet("S14_IVlinear_RD", replace) 


foreach y of local outcome { 
	xmluse "`OUT'/S14_RD_`y'.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using "`OUT'/TableS14", sheet("S14_RD_`y'", replace) 
	}
foreach y of local outcome { 
	xmluse "`OUT'/S14_FzRD_`y'.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using "`OUT'/TableS14", sheet("S14_FzRD_`y'", replace) 
	}


cap erase "`OUT'/S14_poly_RD.xml"
cap erase "`OUT'/S14_poly_RD.txt"
cap erase "`OUT'/S14_linear_RD.xml"
cap erase "`OUT'/S14_linear_RD.txt"
cap erase "`OUT'/S14_IVpoly_RD.xml"
cap erase "`OUT'/S14_IVpoly_RD.txt"
cap erase "`OUT'/S14_IVlinear_RD.xml"
cap erase "`OUT'/S14_IVlinear_RD.txt"

foreach var in ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2  {
	cap erase "`OUT'/S14_RD_`var'.xml"
	cap erase "`OUT'/S14_RD_`var'.txt"
} 

foreach y of local outcome { 
	cap erase "`OUT'/S14_RD_`y'.txt"
	cap erase "`OUT'/S14_RD_`y'.xml" 
	cap erase "`OUT'/S14_FzRD_`y'.txt" 
	cap erase "`OUT'/S14_FzRD_`y'.xml" 	
	} 	
