*======================================================================*
* TABLE S16: Regression discontinuity estimates of the Huai River 
* policy and the impact of PM10 on health outcomes using only
* direct PM10 measurements
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"

//Code
cap erase "`OUT'/S16_simple_diff.xml"
cap erase "`OUT'/S16_simple_diff.txt"
cap erase "`OUT'/S16_poly_diff.xml"
cap erase "`OUT'/S16_poly_diff.txt"
cap erase "`OUT'/S16_linear_diff.xml"
cap erase "`OUT'/S16_linear_diff.txt"
cap erase "`OUT'/S16_IVpoly_RD.xml"
cap erase "`OUT'/S16_IVpoly_RD.txt"
cap erase "`OUT'/S16_IVlinear_RD.xml"
cap erase "`OUT'/S16_IVlinear_RD.txt"

foreach y in r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2 { 
	cap erase "`OUT'/S16_RD_`y'.xml"
	cap erase "`OUT'/S16_RD_`y'.txt" 
	cap erase "`OUT'/S16_FzRD_`y'.xml" 
	cap erase "`OUT'/S16_FzRD_`y'.txt" 
	}



use "`IN'/reg_data_04_12_noT2P_v4.dta", clear

keep if sex == 0
collapse code ex ex5 ex60 population death1 dr1 ajdr1 ///
		 death4 dr4 ajdr4 death10 dr10 ajdr10 death11  ///
		 dr11 ajdr11 sequ dsps90 match urban north_new north_avi dr1_85  ///
		 dr4_85 dr10_85 ex85 dr1_80 dr4_80 dr10_80 ex80 dr1_75 dr4_75 dr10_75  ///
		 ex75 dr1_70 dr4_70 dr10_70 ex70 dr1_65 dr4_65 dr10_65 ex65 dr1_60 dr4_60  ///
		 dr10_60 dr1_55 dr4_55 dr10_55 ex55 dr1_50 dr4_50 dr10_50 ex50 dr1_45  ///
		 dr4_45 dr10_45 ex45 dr1_40 dr4_40 dr10_40 ex40 dr1_35 dr4_35 dr10_35  ///
		 ex35 dr1_30 dr4_30 dr10_30 ex30 dr1_25 dr4_25 dr10_25 ex25 dr1_20 dr4_20  ///
		 dr10_20 ex20 dr1_15 dr4_15 dr10_15 ex15 dr1_10 dr4_10 dr10_10 ex10  ///
		 ajdr5  ajdr7 ajdr13 ajdr19  ajdr6 ajdr22 ///
		 dr1_5 dr4_5 dr10_5 dr1_1 dr4_1 dr10_1 ex1 pm10 ///
		 r03_pm10 so2 r03_so2  ///
		 no2 r03_no2   ///
		 r04_heating_degrees r04_cooling_degrees heating_degrees cooling_degrees  ///
		 temp rainfall  maxtemp  ///
		 mintemp prov_id mshare fshare rshare ushare minoshare  ///
		 mmanufsh fmanufsh v1_manufsh  v5_yrsed ///
		 pref_id sharetapwater_10 sharemin_10 naghukou_10  ///
		 shareurb_10 yrsed_10 illrate_10 unemprate_10 share1ind_10 share2ind_10  ///
		 share3ind_10 sharemanu_10 shareconstr_10 ///
		  dist_avi_revised  ///
		  dist_coast csmk bdrk insvf redmeat  ///
		 inspa owobs hbp poorhealth badsleep bmi sbp biomass vent cdsmk smkexp passmk  ///
		 overdrink sedtime pcincome longitude latitude longitude2 latitude2 longitude3  ///
		 latitude3, by (overall_sequ sex)
		 
		 
replace north_avi = 1 if north_avi == -1
tab north_avi

replace dist_avi_revised = -dist_avi_revised if north_avi == 0


* 1 latitude = 111 km
gen lat_dist_avi_revised = dist_avi_revised/111000


foreach y of var ajdr1 ajdr4 ajdr10 ajdr11 ajdr5 ajdr6 ajdr7 ajdr13 ajdr19 ajdr22 {
gen l_`y'= log(1+`y')
}

foreach y of var dr1 dr1_1 dr1_5 dr1_10 dr1_15 dr1_20 dr1_25 dr1_30 dr1_35 dr1_40 dr1_45 dr1_50 dr1_55 dr1_60 dr1_65 dr1_70 dr1_75 dr1_80 dr1_85 dr10 ///
                 dr10_1 dr10_5 dr10_10 dr10_15 dr10_20 dr10_25 dr10_30 dr10_35 dr10_40 dr10_45 dr10_50 dr10_55 dr10_60 dr10_65 dr10_70 dr10_75 dr10_80 dr10_85 ///
                 dr4 dr4_1 dr4_5 dr4_10 dr4_15 dr4_20 dr4_25 dr4_30 dr4_35 dr4_40 dr4_45 dr4_50 dr4_55 dr4_60 dr4_65 dr4_70 dr4_75 dr4_80 dr4_85 {
gen l_`y' = log(1+`y')
}

gen dist_avi1=lat_dist_avi_revised 
gen dist_avi2=lat_dist_avi_revised^2  
gen dist_avi3=lat_dist_avi_revised^3  
gen dist_avi4=lat_dist_avi_revised^4  
gen dist_avi5=lat_dist_avi_revised^5

gen north_dist1 = north_avi*dist_avi1
gen north_dist2 = north_avi*dist_avi2
gen north_dist3 = north_avi*dist_avi3
gen north_dist4 = north_avi*dist_avi4
gen north_dist5 = north_avi*dist_avi5


gen Lpcincome=log(pcincome) 
replace pcincome = pcincome/1000

replace dist_coast = dist_coast/1000
gen dist_dum100 = 1 if dist_coast <=100
replace dist_dum100 = 0 if dist_coast >100

keep if r03_pm10 != .

merge 1:1 code using $root/Data_Files/PNAS_table16_12.dta

local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  

reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals


local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex"
foreach y of local outcome { 
	local d =2
	if `y'==ex| `y'==r03_pm10{
		local d = 1
	}
	
	reg `y' north_avi [w=population], robust
	outreg2 using "`OUT'/S16_simple_diff", excel stats(coef se pval) ctitle(`y') dec(`d') append 

	reg `y' north_avi `OLS_var' [w=population], robust
	outreg2 using "`OUT'/S16_simple_diff", excel stats(coef se pval) ctitle(`y') dec(`d') append 
	
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/S16_poly_diff", excel stats(coef se pval) dec(`d') append

	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/S16_poly_diff", excel stats(coef se pval) dec(`d') append
	
	reg `y' north_avi dist_avi1 north_dist1 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S16_linear_diff" , excel dec(`d') append 

	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S16_linear_diff" , excel dec(`d') append 

	}




** local linear regression adjusted difference
local kernelfn "tri epa uni"  
local bwmethod "IK CCT CV" 


local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex"
* Authomatic bandwidth models: 
foreach y of local outcome { 

	foreach bvar of local bwmethod { 
  
		foreach kvar of local kernelfn { 
				local d =2
				if `y'==ex | `y'==r03_pm10{
					local d = 1
				}
			rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(`bvar') all 
			outreg2 using "`OUT'/S16_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  ctitle(`dvar') dec(`d') append
			
 			}  	
		
		}
	} 			


* Manually choose bandwidth: 5 degrees
foreach y of local outcome { 
  
	foreach kvar of local kernelfn { 

		rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(IK) h(5) all 
		outreg2 using "`OUT'/S16_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')   ctitle(`dvar') noobs nose  nonotes dec(4) append 
			
		}
	} 


replace r03_pm10=r03_pm10/10 

* 2sls 

local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11"
foreach y of local outcome  {
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S16_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S16_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 north_dist1 (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S16_IVlinear_RD", excel dec(2) append 
	
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S16_IVlinear_RD", excel dec(2) append 
	
	}


local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex"

foreach y of local outcome { 

	foreach bvar of local bwmethod { 
  
		foreach kvar of local kernelfn { 

			rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10) kernel(`kvar') bwselect(`bvar') all 
			outreg2 using "`OUT'/S16_FzRD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)') ctitle(`y')  dec(2) append 

 			}  	
		
		}
	} 	
	
* Output: Table S16
xmluse "`OUT'/S16_simple_diff.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS16", sheet("S16_simple_diff", replace) 

xmluse "`OUT'/S16_poly_diff.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS16", sheet("S16_poly_diff", replace) 

xmluse "`OUT'/S16_linear_diff.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS16", sheet("S16_linear_diff", replace) 

xmluse "`OUT'/S16_IVpoly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS16", sheet("S16_IVpoly_RD", replace) 

xmluse "`OUT'/S16_IVlinear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS16", sheet("S16_IVlinear_RD", replace) 


local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex"
foreach y of local outcome { 
	xmluse "`OUT'/S16_RD_`y'", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using "`OUT'/TableS16", sheet("S16_RD_`y'", replace) 
	}


local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex"
foreach y of local outcome { 
	xmluse "`OUT'/S16_FzRD_`y'", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
	export excel using "`OUT'/TableS16", sheet("S16_FzRD_`y'", replace) 
	}

	
cap erase "`OUT'/S16_simple_diff.xml"
cap erase "`OUT'/S16_simple_diff.txt"
cap erase "`OUT'/S16_poly_diff.xml"
cap erase "`OUT'/S16_poly_diff.txt"
cap erase "`OUT'/S16_linear_diff.xml"
cap erase "`OUT'/S16_linear_diff.txt"
cap erase "`OUT'/S16_IVpoly_RD.xml"
cap erase "`OUT'/S16_IVpoly_RD.txt"
cap erase "`OUT'/S16_IVlinear_RD.xml"
cap erase "`OUT'/S16_IVlinear_RD.txt"

foreach y in r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2 { 
	cap erase "`OUT'/S16_RD_`y'.xml"
	cap erase "`OUT'/S16_RD_`y'.txt"
	cap erase "`OUT'/S16_FzRD_`y'.xml" 
	cap erase "`OUT'/S16_FzRD_`y'.txt" 
}

