*======================================================================*
* TABLE S17: Regression discontinuity estimates of the change in 
* predicted and residual life expectancy at the Huai River
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"

//CODE
cap erase "`OUT'/T2_poly_RD.txt"
cap erase "`OUT'/T2_poly_RD.xml"
cap erase "`OUT'/T2_linear_RD.txt"
cap erase "`OUT'/T2_linear_RD.xml"

use "`IN'/RD_data_merged.dta", clear

* Leaves us with 154 observations out of 161.
keep if pm10 != .

* Controls & Outcomes
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100   medservice r2003_Level" 
local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2"  

* Getting Predicted Life Expectancy
reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals


** column 1-4

* Linear and Polynomial Regressions
foreach y of local outcome {
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/T2_poly_RD", excel dec(1) append

	* Maoyong add OUT with controls 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/T2_poly_RD", excel dec(1) append


	reg `y' north_avi dist_avi1 north_dist1 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/T2_linear_RD" , excel dec(1) append 
	
	* Maoyong add OUT with controls 
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust 
	outreg2 using "`OUT'/T2_linear_RD" , excel dec(1) append 	
	
	}
	
	
	
** Columns 5-7

* The Outcomes, Bandwidth Methods and Kernels
local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2" 
local kernelfn "tri epa uni"  
local bwmethod "CCT IK CV" 


* Preventing results from no changing	
foreach y of local outcome { 
	cap erase "`OUT'/T2_RD_`y'.txt" 
	cap erase "`OUT'/T2_RD_`y'.xml"
	cap erase "`OUT'/T2_FzRD_`y'.txt"
	cap erase "`OUT'/T2_FzRD_`y'.xml"
	} 	
	

* RD Regressions

* Authomatic bandwidth models: 
foreach y of local outcome { 
	
	foreach bvar of local bwmethod { 
	  
		foreach kvar of local kernelfn { 
	
			rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(`bvar') all 
					
				outreg2 using "`OUT'/T2_RD_`y'", excel addstat(Conventional Std. Err., e(se_cl), Conventional p-value, e(pv_cl),      ///
				Bias-corrected Std. Err., e(se_cl), Bias-corrected p-value, e(pv_bc),  Robust Std. Err., e(se_rb), Robust p-value, e(pv_rb), Order Loc. Poly. (p), e(p), Order        ///
				Bias (q), e(q), BW Loc. Poly. (h), e(h_bw), BW Bias (b),e(b_bw))              ///
				addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')     ///
				title(`dvar') noobs nose nonotes adec(1) dec(1) append 
			}  	
			
		}
	} 			
	
	
* Manually choose bandwidth: 5 degrees
foreach y of local outcome { 
	  
	foreach kvar of local kernelfn { 
	
			rdrobust `y' lat_dist_avi_revised, kernel(`kvar') h(5) all 
			* set bandwidth to 5 degrees
			outreg2 using "`OUT'/T2_RD_`y'", excel addstat(Conventional Std. Err., e(se_cl), Conventional p-value, e(pv_cl),      ///
			Bias-corrected Std. Err., e(se_cl), Bias-corrected p-value, e(pv_bc),  Robust Std. Err., e(se_rb), Robust p-value, e(pv_rb), Order Loc. Poly. (p), e(p), Order        ///
			Bias (q), e(q), BW Loc. Poly. (h), e(h_bw), BW Bias (b),e(b_bw))              ///
			addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')     ///
			ctitle(`dvar') noobs nose  nonotes adec(1) dec(1) append 
			}
		}
		
* fuzzy local linear (for table s10)

local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex" 
replace r03_pm10=r03_pm10/10 

* Authomatic bandwidth models: 
foreach y of local outcome { 
	
	foreach bvar of local bwmethod { 
	  
		foreach kvar of local kernelfn { 
	
			rdrobust `y' lat_dist_avi_revised,  fuzzy(r03_pm10) kernel(`kvar') bwselect(`bvar') all 					
			outreg2 using "`OUT'/T2_FzRD_`y'", excel 	addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  ctitle(`dvar')  dec(1) append 
	 		
			}  	
			
		}
	} 			

* Manually choose bandwidth: 5 degrees
foreach y of local outcome { 
	  
	foreach kvar of local kernelfn { 
	
		rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10) kernel(`kvar')  bwselect(IK) h(5) all 
		outreg2 using "`OUT'/T2_FzRD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')   ctitle(`dvar') dec(1) append 
		}
	} 

	
* Outputting Table 2
xmluse "`OUT'/T2_poly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_poly_RD", replace) 
	
xmluse "`OUT'/T2_linear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_linear_RD", replace) 
	
xmluse "`OUT'/T2_RD_r03_pm10.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_PM10", replace) 
	
xmluse "`OUT'/T2_RD_ex.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_ex", replace) 
	
xmluse "`OUT'/T2_RD_ex5.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_ex5", replace) 
	
xmluse "`OUT'/T2_RD_ex60.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_ex60", replace) 
	
xmluse "`OUT'/T2_RD_l_ajdr4.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_l_ajdr4", replace) 
	
xmluse "`OUT'/T2_RD_resid_ex.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_resid_ex", replace) 
	
xmluse "`OUT'/T2_RD_l_ajdr10.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_l_ajdr10", replace) 
	
xmluse "`OUT'/T2_RD_l_ajdr11.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_l_ajdr11", replace) 
	
xmluse "`OUT'/T2_RD_pred_ex.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_pred_ex", replace) 
	
xmluse "`OUT'/T2_RD_r03_no2.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_RD_no2", replace) 

xmluse "`OUT'/T2_FzRD_ex.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_ex", replace) 
	
xmluse "`OUT'/T2_FzRD_ex5.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_ex5", replace) 
	
xmluse "`OUT'/T2_FzRD_ex60.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_ex60", replace) 
	
xmluse "`OUT'/T2_FzRD_l_ajdr4.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_l_ajdr4", replace) 
	
xmluse "`OUT'/T2_FzRD_resid_ex.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_resid_ex", replace) 
	
xmluse "`OUT'/T2_FzRD_l_ajdr10.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_l_ajdr10", replace) 
	
xmluse "`OUT'/T2_FzRD_l_ajdr11.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_l_ajdr11", replace) 
	
xmluse "`OUT'/T2_FzRD_pred_ex.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS17", sheet("T2_FzRD_pred_ex", replace) 


* Cleaning Up The Folder for Less Clutter
local outcome "r03_pm10 ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11 pred_ex r03_no2" 
cap erase "`OUT'/T2_poly_RD.txt"
cap erase "`OUT'/T2_poly_RD.xml"
cap erase "`OUT'/T2_linear_RD.txt"
cap erase "`OUT'/T2_linear_RD.xml"

foreach y of local outcome { 
	cap erase "`OUT'/T2_RD_`y'.txt" 
	cap erase "`OUT'/T2_RD_`y'.xml"
	cap erase "`OUT'/T2_FzRD_`y'.txt" 
	cap erase "`OUT'/T2_FzRD_`y'.xml"	
	} 	
