*======================================================================*
* TABLE S18: Robustness chekcs of choice of functional form for 
* distance from the coast
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"

//CODE
cap erase "`OUT'/S18_poly_RD.txt"
cap erase "`OUT'/S18_poly_RD.xml"
cap erase "`OUT'/S18_linear_RD.txt"
cap erase "`OUT'/S18_linear_RD.xml"
cap erase "`OUT'/S18_IVpoly_RD.xml"
cap erase "`OUT'/S18_IVpoly_RD.txt"
cap erase "`OUT'/S18_IVlinear_RD.xml"
cap erase "`OUT'/S18_IVlinear_RD.txt"

use "`IN'/RD_data_merged.dta", clear

* Leaves us with 154 observations out of 161.
keep if r03_pm10 != .

* Controls & Outcomes
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100   medservice r2003_Level" 
local outcome "r03_pm10 ex l_ajdr4  l_ajdr10"  

* Getting Predicted Life Expectancy
reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals

*Generate Quadratic Distance from Coast Term
gen dist_coast2 = dist_coast^2

** column 1-4

* Linear and Polynomial Regressions
foreach y of local outcome {
	local d = 2
	if 	`y' == ex | `y'== r03_pm10{
		local d = 1
	}
	
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 dist_coast [w=population], robust
	outreg2 using "`OUT'/S18_poly_RD", excel dec(`d') append

	* Maoyong add OUT with controls 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' dist_coast [w=population], robust
	outreg2 using "`OUT'/S18_poly_RD", excel dec(`d') append


	reg `y' north_avi dist_avi1 north_dist1 dist_coast [w=population] if dist_avi1>=-5 & dist_avi1<=5  , robust
	outreg2 using "`OUT'/S18_linear_RD" , excel dec(`d') append 
	
	* Maoyong add OUT with controls 
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' dist_coast [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust 
	outreg2 using "`OUT'/S18_linear_RD" , excel dec(`d') append 	
	
	}

** column 5-8
* Linear and Polynomial Regressions
foreach y of local outcome {
	local d = 2
	if 	`y' == ex | `y'==r03_pm10{
		local d = 1
	}
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 dist_coast dist_coast2 [w=population], robust
	outreg2 using "`OUT'/S18_poly_RD", excel dec(`d') append

	* Maoyong add OUT with controls 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' dist_coast dist_coast2 [w=population], robust
	outreg2 using "`OUT'/S18_poly_RD", excel dec(`d') append


	reg `y' north_avi dist_avi1 north_dist1 dist_coast dist_coast2 [w=population] if dist_avi1>=-5 & dist_avi1<=5  , robust
	outreg2 using "`OUT'/S18_linear_RD" , excel dec(`d') append 
	
	* Maoyong add OUT with controls 
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' dist_coast dist_coast2 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust 
	outreg2 using "`OUT'/S18_linear_RD" , excel dec(`d') append 	
	
	}	

**IV 2SLS
** Columns 1-4
replace r03_pm10 = r03_pm10/10

local outcome " ex l_ajdr4 "  

foreach y of local outcome  {
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 dist_coast (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S18_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var'  dist_coast (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S18_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 north_dist1 dist_coast (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S18_IVlinear_RD", excel dec(2) append 
	
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' dist_coast (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S18_IVlinear_RD", excel dec(2) append 
	
	}
	
foreach y of local outcome  {
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 dist_coast dist_coast2 (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S18_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var'  dist_coast dist_coast2 (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S18_IVpoly_RD", excel dec(2) append
	
	ivregress 2sls `y' dist_avi1 north_dist1 dist_coast dist_coast2 (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S18_IVlinear_RD", excel dec(2) append 
	
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' dist_coast dist_coast2 (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5  
	outreg2 using "`OUT'/S18_IVlinear_RD", excel dec(2) append 
	
	}

* Outputting Table S18
xmluse "`OUT'/S18_poly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS18", sheet("S18_poly_RD", replace) 
	
xmluse "`OUT'/S18_linear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS18", sheet("S18_linear_RD", replace) 

xmluse "`OUT'/S18_IVpoly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS18", sheet("S18_IVpoly_RD", replace) 

xmluse "`OUT'/S18_IVlinear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS18", sheet("S18_IVlinear_RD", replace) 


* Cleaning Up The Folder for Less Clutter
cap erase "`OUT'/S18_poly_RD.txt"
cap erase "`OUT'/S18_poly_RD.xml"
cap erase "`OUT'/S18_linear_RD.txt"
cap erase "`OUT'/S18_linear_RD.xml"
cap erase "`OUT'/S18_IVpoly_RD.xml"
cap erase "`OUT'/S18_IVpoly_RD.txt"
cap erase "`OUT'/S18_IVlinear_RD.xml"
cap erase "`OUT'/S18_IVlinear_RD.txt"

