*======================================================================*
* TABLE S19: Patterns in other government policies south and north of the
* Huai River among DSP locations
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"


//Code
cap erase "`OUT'/S19_simple_diff.xml"
cap erase "`OUT'/S19_simple_diff.txt"
cap erase "`OUT'/S19_poly_diff.xml"
cap erase "`OUT'/S19_poly_diff.txt"
cap erase "`OUT'/S19_linear_diff.xml"
cap erase "`OUT'/S19_linear_diff.txt"


use "`IN'/RD_data_merged.dta", clear
matrix joint_test = (1,1)

drop if overall_sequ==. 
keep if r03_pm10 != .


gen DSP_125 = 1 if !missing(v200_pc) & !missing(hospital_pc) & !missing(watertreatrate) & !missing(wastetreatrate)
replace DSP_125=0 if DSP_125==.


replace v200_pc=. if DSP_125==0
replace hospital_pc=. if DSP_125==0
replace wastetreatrate=. if DSP_125==0
replace watertreatrate=. if DSP_125==0


local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100  medservice r2003_Level v200_pc hospital_pc  watertreatrate wastetreatrate"  
reg ex `OLS_var' [w=population], robust
predict pred_ex


//gen hospital_pc = hospital/pop_ceic

**only keep observations that have all four variables: v200_pc hospital_pc  watertreatrate wastetreatrate
keep if !missing(v200_pc) & !missing(hospital_pc) & !missing(watertreatrate) & !missing(wastetreatrate)
count 

** Columns 1 and 2 Differences in Means
 
local outcome "v200_pc hospital_pc  watertreatrate wastetreatrate pred_ex"
sum `outcome' [w=population] if north_avi == 1, sep(0)
sum `outcome' [w=population] if north_avi == 0, sep(0)

	**North Summary Stats
	putexcel set "`OUT'/TableS19.xls", sheet(Col_1_2_north, replace) modify 
	putexcel A1=("Var Name") B1=("Mean") C1=("SD")
	local i = 2
	foreach v of var `outcome' {
		sum `v' [w=population] if north_avi == 1, sep(0) 
		putexcel A`i'=("`v'") B`i' = ("`r(mean)'") C`i'=("`r(sd)'")
		local i = `i'+1
	}

	**South Summary Stats
	putexcel set "`OUT'/TableS19.xls", sheet(Col_1_2_south, replace) modify 
	putexcel A1=("Var Name") B1=("Mean") C1=("SD")
	local i = 2
	foreach v of var `outcome' {
		sum `v' [w=population] if north_avi == 0, sep(0) 
		putexcel A`i'=("`v'") B`i' = ("`r(mean)'") C`i'=("`r(sd)'")
		local i = `i'+1
	}
	
** polynomial differences
foreach y of local outcome { 
	local d = 1
	if "`y'" == "hospital_pc"{
		local d =2
	}
	
	reg `y' north_avi [w=population], robust
	outreg2 using "`OUT'/S19_simple_diff", excel ctitle(`y') dec(`d') append 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/S19_poly_diff", excel dec(`d') append
	reg `y' north_avi dist_avi1 north_dist1 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S19_linear_diff" , excel dec(`d') append 
}

** local linear regression adjusted difference
local kernelfn "tri epa uni"  
local bwmethod "IK CCT CV" 

foreach y of local outcome { 
	cap erase "`OUT'/S19_RD_`y'.txt" 
	cap erase "`OUT'/S19_RD_`y'.xml" 
} 	

* Authomatic bandwidth models: 
foreach y of local outcome { 

	foreach bvar of local bwmethod { 
  
		foreach kvar of local kernelfn { 
					local d = 1
						if "`y'" == "hospital_pc"{
						local d =2
					}
				rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(`bvar') all 
				
					outreg2 using "`OUT'/S19_RD_`y'",  excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  ctitle(`y') dec(`d') append 
 			}  	
		
		}
	} 			

* Manually choose bandwidth: 5 degrees
foreach y of local outcome { 
  
		foreach kvar of local kernelfn { 

				rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(IK) h(5) all 
				* set bandwidth to 5 degrees
					outreg2 using "`OUT'/S19_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  ctitle(`y') dec(2) append  
		}
	} 

	
	

*Panel C	
	
use "`IN'/RD_data_merged.dta", clear

drop if overall_sequ==. 
keep if r03_pm10 != .

	
*Joint Tests
local All_var "r03_pm10 r03_so2 r03_no2 r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare  dist_dum100 smkexp bdrk redmeat inspa ex ex5 ex60 l_ajdr4 l_ajdr10 l_ajdr11  medservice r2003_Level v200_pc hospital_pc  watertreatrate wastetreatrate"

gen DSP_125 = 1 if !missing(v200_pc) & !missing(hospital_pc) & !missing(watertreatrate) & !missing(wastetreatrate)
replace DSP_125=0 if DSP_125==.


replace v200_pc=. if DSP_125==0
replace hospital_pc=. if DSP_125==0
replace wastetreatrate=. if DSP_125==0
replace watertreatrate=. if DSP_125==0


**Joint test of significance

**Simple Diff
		foreach y of var `All_var' { 
			reg `y' north_avi [w=population]
			est store `y'
			}
			suest `All_var', robust

		**Using covariates from Panel B and C
		test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi [wastetreatrate_mean]north_avi [watertreatrate_mean]north_avi [v200_pc_mean]north_avi [hospital_pc_mean]north_avi 
		matrix joint_test = (joint_test \ r(chi2), r(p))
	
**Polynomial Diff
	foreach y of var `All_var' { 
		qui reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population]
		est store `y'
		}
	suest `All_var', robust	

	**Using covariates from Panel B and C
	test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi [wastetreatrate_mean]north_avi [watertreatrate_mean]north_avi [v200_pc_mean]north_avi [hospital_pc_mean]north_avi 
	matrix joint_test = (joint_test \ r(chi2), r(p))
		

***Local Lin Diff
	matrix bandwidths = (1)
	foreach y of var `All_var' {
		 rdrobust `y' lat_dist_avi_revised, kernel(uni) bwselect(IK)
		matrix bandwidths = (bandwidths \ e(h_bw))
	}
	
	local i = 2
	**Joint test of significance
		foreach y of var `All_var' { 
			qui reg `y' north_avi dist_avi1 north_dist1 if dist_avi1 < bandwidths[`i',1] & dist_avi1 > -bandwidths[`i',1]
			est store `y'
			local i = `i' + 1
			}
		suest `All_var', robust	

	test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi [medservice_mean]north_avi [r2003_Level_mean]north_avi [wastetreatrate_mean]north_avi [watertreatrate_mean]north_avi [v200_pc_mean]north_avi [hospital_pc_mean]north_avi 
	//test [r04_heating_degrees_mean]north_avi [r04_cooling_degrees_mean]north_avi [rainfall_mean]north_avi [pcincome_mean]north_avi [v5_yrsed_mean]north_avi [minoshare_mean]north_avi [dist_dum100_mean]north_avi [smkexp_mean]north_avi [bdrk_mean]north_avi [redmeat_mean]north_avi [inspa_mean]north_avi  [medservice_mean]north_avi [r2003_Level_mean]north_avi 

	matrix joint_test = (joint_test \ r(chi2), r(p))	
	
*Export joint test results	
putexcel set "`OUT'/TableS19.xls", sheet(joint, replace)  modify
putexcel A1 = matrix(joint_test), names nformat(number_d2)
	
	
** Output: Table S19 **

local outcome "v200_pc hospital_pc  watertreatrate wastetreatrate pred_ex"

xmluse "`OUT'/S19_simple_diff.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS19", sheet("S19_simple_diff", replace) 

xmluse "`OUT'/S19_poly_diff.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS19", sheet("S19_poly_diff", replace) 

xmluse "`OUT'/S19_linear_diff.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS19", sheet("S19_linear_diff", replace) 

foreach y of local outcome { 
xmluse "`OUT'/S19_RD_`y'", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS19", sheet("S19_RD_`y'", replace) 
}


cap erase "`OUT'/S19_simple_diff.xml"
cap erase "`OUT'/S19_simple_diff.txt"
cap erase "`OUT'/S19_poly_diff.xml"
cap erase "`OUT'/S19_poly_diff.txt"
cap erase "`OUT'/S19_linear_diff.xml"
cap erase "`OUT'/S19_linear_diff.txt"
foreach y of local outcome { 
	cap erase "`OUT'/S19_RD_`y'.txt" 
	cap erase "`OUT'/S19_RD_`y'.xml" 
} 		
clear
