*======================================================================*
* TABLE S20: Regression discontinuity estimates of change in log
* population at the Huai River
*======================================================================*

#delimit ; 

set more off ;     pause on ;   
tempfile quxian xianchen BBB ;  

global result /Users/`c(username)'/Desktop/Huai_River_Replication_Files/Do_Files/Results;
global path /Users/`c(username)'/Desktop/Huai_River_Replication_Files;  
cd $path;                            

*** Merge distance from each county to Huai River with census 2010 ; 

	import excel $path/Data_Files/quxian_centroid_huai_dist_Faraz.xlsx, sheet("Sheet1") firstrow clear ;  
	ren CNTY_CODE county_code ; 
	gen north= NEAR_ANGLE<0 ;    * 
	* gen north= NEAR_ANGLE=0 ;       
	gen lat_dist = NEAR_DIST/111000 ; 
	replace lat_dist=-lat_dist if north==0 ;  
	
	bysort county_code: gen x=_N ;
	* edit if x>1 ; 
	drop if county_code==0 ;  
	
	
	merge 1:1 county_code using $path/Data_Files/census_county_2010.dta ; 
	list NAME if _merge==1 ; 
	list name province city county lat_dist if _merge==2 ; 
	drop if _merge==1 ; 
	drop _merge ; 
	save `quxian', replace ;  


use $path/Data_Files/RD_data_merged, clear ;  
unique code ; 
keep if r03_pm10~=. ; 
unique code ; 
gen DSP=1 ; 
keep code DSP dist_avi1 north_avi; 
ren code county_code ;   
merge 1:1 county_code using `quxian' ; 

*Replace north indicators and distance variables for DSP Locations;
replace north=north_avi if DSP==1;
replace lat_dist=dist_avi1 if DSP==1;

gen lat_dist1=lat_dist;  
gen lat_dist2=lat_dist^2 ;  
gen lat_dist3=lat_dist^3 ;  

gen north_dist1=north*lat_dist1 ;  
gen north_dist2=north*lat_dist2 ;  
gen north_dist3=north*lat_dist3 ;  

drop north_avi dist_avi1; 

save `quxian', replace ;   



*** Table S20 ; 

use `quxian', clear ; 

* gen y=int(county_code/10000) ; 
* drop if y==31 ;  * drop shanghai ; 

gen pop_density=totpop/AREA ; 
gen urban_density=urbanpop/AREA ; 
gen rural_density=ruralpop/AREA ;  

gen Ltotpop=log(totpop) ; 

cap erase $result/poly_RD.txt ; 
cap erase $result/poly_RD.xml ; 
cap erase $result/local_RD.txt ; 
cap erase $result/local_RD.xml ; 

local outcome "Ltotpop" ; 

foreach y of local outcome { ; 

	reg `y' north lat_dist1 lat_dist2 lat_dist3 north_dist1 north_dist2 north_dist3, robust ; 
	outreg2 using $result/poly_RD, excel dec(2) append ; 
	reg `y' north lat_dist1 north_dist1  if lat_dist>=-5 & lat_dist<=5, robust ;  
	outreg2 using $result/poly_RD, excel dec(2) append ; 
	reg `y' north lat_dist1 lat_dist2 lat_dist3 north_dist1 north_dist2 north_dist3 if DSP==1, robust ;  
	outreg2 using $result/poly_RD, excel dec(2) append ; 
	reg `y' north lat_dist1 north_dist1 if lat_dist>=-5 & lat_dist<=5 & DSP==1, robust ;  
	outreg2 using $result/poly_RD, excel dec(2) append ; 
	
	
	local kernelfn "tri epa uni"   ; 
	local bwmethod "IK CCT CV"     ; 

	
	foreach bvar of local bwmethod { ; 
		foreach kvar of local kernelfn { ; 
	
				rdrobust `y' lat_dist, kernel(`kvar') bwselect(`bvar') all ; 
				outreg2 using $result/local_RD, excel 	addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`dvar') dec(2) append ;  
		
		} ; 
	} ;  
	 			
	foreach bvar of local bwmethod { ; 
		foreach kvar of local kernelfn { ; 
	
				rdrobust `y' lat_dist if DSP==1, kernel(`kvar') bwselect(`bvar') all ; 
				outreg2 using $result/local_RD, excel 	addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Bandwidth, `e(h_bw)', Observations, `e(N)') ctitle(`dvar') dec(2) append ;  
		
		} ; 
	} ;  
 		
} ;  


*** Output Table *** ; 
xmluse $result/poly_RD.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear ; 
export excel using $result/TableS20, sheet("poly_RD", replace) ; 

xmluse $result/local_RD.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear ; 
export excel using $result/TableS20, sheet("local_RD", replace) ;  
