*======================================================================*
* TABLE S21: Regression discontinuity estimates of out-migration
* and migration-weighted PM10 exposure at the Huai River
*======================================================================*


clear
set more off 

global path    /Users/`c(username)'/Desktop/Huai_River_Replication_Files
global result   /Users/`c(username)'/Desktop/Huai_River_Replication_Files/Do_Files/Results

use $path/Data_Files/census2005_county_DSP.dta, clear

keep if DSP_loc==1

cap erase  $result/full_llnr.xml
cap erase  $result/full_llnr.txt
cap erase  $result/full_poly.xml
cap erase  $result/full_poly.txt
cap erase  $result/full_linear.xml
cap erase  $result/full_linear.txt 


**Count migrants and total individuals**
	putexcel set $result/TableS21, sheet(counts, replace) modify
	*Full Sample 
		count
		putexcel A1 = (`r(N)')
		count if migrant==1 
		putexcel A2 = (`r(N)')
		
		su pm10_hukou 
		putexcel A3 = (`r(mean)')
		putexcel A4 = (`r(sd)')
		
		su pol_diff_all if migrant==1 
		putexcel A5 = (`r(mean)')
		putexcel A6 = (`r(sd)')
		
	*Age Groups
	local cell = "B C D E F G H"
	local x = 0
		foreach v of local cell{
			local x = `x'+10
			if `x'==70{
				count if age >=`x'-10
				putexcel `v'1 = (`r(N)')
	
				count if  migrant==1 & age >=`x' -10
				putexcel `v'2 = (`r(N)')
							
				su pm10_hukou if age >=`x'-10
				putexcel `v'3 = (`r(mean)')
				putexcel `v'4 = (`r(sd)')
				
				su pol_diff_all if migrant==1 & age >=`x'-10
				putexcel `v'5 = (`r(mean)')
				putexcel `v'6 = (`r(sd)')
			}
			
			else{
				count if age >=`x'-10 & age <= `x' -1
				putexcel `v'1 = (`r(N)')
	
				count if  migrant==1 & age >=`x'-10 & age <= `x' -1
				putexcel `v'2 = (`r(N)')
							
				su pm10_hukou if age >=`x'-10 & age <= `x' -1
				putexcel `v'3 = (`r(mean)')
				putexcel `v'4 = (`r(sd)')
				
				su pol_diff_all if migrant==1 & age >=`x'-10 & age <= `x' -1
				putexcel `v'5 = (`r(mean)')
				putexcel `v'6 = (`r(sd)')
			}
		}



**MIGRATION DISCONTINUTIES
	*Full Sample 
			preserve 
			bysort hukou_county: gen population = _N
			
			collapse (mean) migrant north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  population, by (hukou_county)					
			
		
			*Local Linear
			rdrobust migrant dist_hk1, kernel(tri) bwselect(IK) 
			outreg2 using $result/full_llnr, excel addstat(bandwidth, `e(h_bw)') dec(2) 
			
			rdrobust migrant dist_hk1, kernel(epa) bwselect(IK) 
			outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(2) 

			rdrobust migrant dist_hk1, kernel(uni) bwselect(IK) 
			outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(2) 
			
			*Polynomial
			reg migrant north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  [w=population], robust
			outreg2 using $result/full_poly, excel dec(2) 

			*Linear Restricted to 5-degrees
			reg migrant north_hukou dist_hk1 dist_hk1_n if dist_hk1 <5 & dist_hk1 > -5 [w=population],robust 
			outreg2 using $result/full_linear, excel dec(2) 
			restore

		*Age Groups
		forvalues x=10(10)70{
			if `x'==70{
				preserve 
				keep if age >= `x' -10
				bysort hukou_county: gen population = _N
			
				collapse (mean) migrant north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  population, by (hukou_county)

				*Local Linear
				rdrobust migrant dist_hk1, kernel(tri) bwselect(IK) 
				outreg2 using $result/full_llnr, excel dec(2) addstat(bandwidth, `e(h_bw)') append

				rdrobust migrant dist_hk1, kernel(epa) bwselect(IK) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(2) 

				rdrobust migrant dist_hk1, kernel(uni) bwselect(IK) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(2) 
				
				*Polynomial
				reg migrant north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  [w=population], robust
				outreg2 using $result/full_poly, excel dec(2) append

				*Linear Restricted to 5-degrees
				reg migrant north_hukou dist_hk1 dist_hk1_n if dist_hk1 <5 & dist_hk1 > -5 [w=population],robust 
				outreg2 using $result/full_linear, excel dec(2) append

				restore
				}
			
			else{
				preserve 
				keep if age <= `x' -1 & age >= `x'-10
				
				bysort hukou_county: gen population = _N
				collapse (mean) migrant north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  population, by (hukou_county)

				*Local Linear
				rdrobust migrant dist_hk1, kernel(tri) bwselect(IK) 
				outreg2 using $result/full_llnr, excel dec(2) addstat(bandwidth, `e(h_bw)') append

				rdrobust migrant dist_hk1, kernel(epa) bwselect(IK) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(2) 

				rdrobust migrant dist_hk1, kernel(uni) bwselect(IK) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(2) 
				
				
				*Polynomial
				reg migrant north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  [w=population], robust
				outreg2 using $result/full_poly, excel dec(2) append

				*Linear Restricted to 5-degrees
				reg migrant north_hukou dist_hk1 dist_hk1_n if dist_hk1 <5 & dist_hk1 > -5 [w=population],robust 
				outreg2 using $result/full_linear, excel dec(2) append

				restore	
			}
		}


**Weighted pollution DISCONTINUTIES
**tri 9.296906624889731 epa 8.654184073339675 uni 7.307397293667025

		*Full Sample 
			preserve 
			bysort hukou_county: gen population = _N
			
			collapse (mean) weight_pol north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  population, by (hukou_county)					
			
		
			*Local Linear
			rdrobust weight_pol dist_hk1, kernel(tri) h(9.296906624889731) 
			outreg2 using $result/full_llnr, excel addstat(bandwidth, `e(h_bw)') dec(1) 
			
			rdrobust weight_pol dist_hk1, kernel(epa) h(8.654184073339675)
			outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(1) 

			rdrobust weight_pol dist_hk1, kernel(uni) h(7.307397293667025)
			outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(1) 
			
			*Polynomial
			reg weight_pol north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  [w=population], robust
			outreg2 using $result/full_poly, excel dec(1) 

			*Linear Restricted to 5-degrees
			reg weight_pol north_hukou dist_hk1 dist_hk1_n if dist_hk1 <5 & dist_hk1 > -5 [w=population],robust 
			outreg2 using $result/full_linear, excel dec(1) 
			restore

		*Age Groups
		forvalues x=10(10)70{
			if `x'==70{
				preserve 
				keep if age >= `x'-10
				bysort hukou_county: gen population = _N
			
				collapse (mean) weight_pol north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  population, by (hukou_county)

				*Local Linear
				rdrobust weight_pol dist_hk1, kernel(tri) h(9.296906624889731)
				outreg2 using $result/full_llnr, excel dec(1) addstat(bandwidth, `e(h_bw)') append

				rdrobust weight_pol dist_hk1, kernel(epa) h(8.654184073339675) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(1) 

				rdrobust weight_pol dist_hk1, kernel(uni) h(7.307397293667025)
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(1) 
				
				*Polynomial
				reg weight_pol north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  [w=population], robust
				outreg2 using $result/full_poly, excel dec(1) append

				*Linear Restricted to 5-degrees
				reg weight_pol north_hukou dist_hk1 dist_hk1_n if dist_hk1 <5 & dist_hk1 > -5 [w=population],robust 
				outreg2 using $result/full_linear, excel dec(1) append

				restore
				}
			
			else{
				preserve 
				keep if age <= `x' -1 & age >= `x'-10
				
				bysort hukou_county: gen population = _N
				collapse (mean) weight_pol north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  population, by (hukou_county)

				*Local Linear
				rdrobust weight_pol dist_hk1, kernel(tri) h(9.296906624889731) 
				outreg2 using $result/full_llnr, excel dec(1) addstat(bandwidth, `e(h_bw)') append

				rdrobust weight_pol dist_hk1, kernel(epa) h(8.654184073339675) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(1) 

				rdrobust weight_pol dist_hk1, kernel(uni) h(7.307397293667025) 
				outreg2 using $result/full_llnr, append excel addstat(bandwidth, `e(h_bw)') dec(1) 
				
				
				*Polynomial
				reg weight_pol north_hukou dist_hk1 dist_hk2 dist_hk3 dist_hk1_n dist_hk2_n dist_hk3_n  [w=population], robust
				outreg2 using $result/full_poly, excel dec(1) append

				*Linear Restricted to 5-degrees
				reg weight_pol north_hukou dist_hk1 dist_hk1_n if dist_hk1 <5 & dist_hk1 > -5 [w=population],robust 
				outreg2 using $result/full_linear, excel dec(1) append

				restore	
			}
		}
			

//Full Sample Average % OF LIFE SPENT AT HUKOU
		matrix average_life = (1,1)
		**Full Sample
		su weight_hukou 
		matrix average_life = (average_life \ `r(mean)' , `r(sd)')

		*Age Groups		
		forvalues x=10(10)70{
			if `x'==70{
				su weight_hukou if age >= `x' -10
				matrix average_life = (average_life \ `r(mean)' , `r(sd)')
			}
			
			else{
				su weight_hukou if age <= `x' -1 & age >= `x'-10
				matrix average_life = (average_life \ `r(mean)' , `r(sd)')

			}
		}		
		
		putexcel set $result/TableS21, sheet(average_life, replace) modify
		putexcel A1 = matrix(average_life)

//Migrant AVerage % OF LIFE SPENT AT HUKOU
		matrix average_life_migrant = (1,1)
		**Full Sample
		su weight_hukou if migrant==1
		matrix average_life_migrant = (average_life_migrant \ `r(mean)' , `r(sd)')

		*Age Groups		
		forvalues x=10(10)70{
			if `x'==70{
				su weight_hukou if age >= `x'-10  & migrant==1
				matrix average_life_migrant = (average_life_migrant \ `r(mean)' , `r(sd)')
			}
			
			else{
				su weight_hukou if age <= `x' -1 & age >= `x'-10 & migrant==1
				matrix average_life_migrant = (average_life_migrant \ `r(mean)' , `r(sd)')

			}
		}		
		
		putexcel set $result/TableS21, sheet(average_life_migrant, replace) modify
		putexcel A1 = matrix(average_life_migrant)		
	
	
**Export
		
		local files "full_poly full_linear"

		foreach file of local files{
			xmluse $result/`file'.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
			export excel using $result/TableS21.xlsx, sheet("`file'", replace) 	
		}
		xmluse $result/full_llnr.xml, doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
		export excel using $result/TableS21.xlsx, sheet(full_llnr, replace) 	

	
cap erase  $result/full_llnr.xml
cap erase  $result/full_llnr.txt
cap erase  $result/full_poly.xml
cap erase  $result/full_poly.txt
cap erase  $result/full_linear.xml
cap erase  $result/full_linear.txt 
