*======================================================================*
* TABLE S22: Coefficient robustness to unobservable selection based on 
* Oster (2016)
*======================================================================*

clear
set more off 

global path /Users/`c(username)'/Desktop/Huai_River_Replication_Files

ssc install psacalc
ssc install matsave

***** Table S22 RD Results *****

	use "$path/RD_data_merged.dta", clear
	keep if r03_pm10 != .
	
	*Controls
	local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  
	
	*Outcomes
	local outcome "r03_pm10 ex l_ajdr4 l_ajdr10"  
	
	matrix coeff_r03_pm10 = (1,1,1)
	matrix coeff_ex = (1,1,1)
	matrix coeff_l_ajdr4 = (1,1,1)
	matrix coeff_l_ajdr10 = (1,1,1)
	
	foreach y of local outcome {
		preserve
		*Full Sample
				* Baseline Regressions
				reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
				matrix coeff_`y' = (coeff_`y' \ _b[north_avi],  _se[north_avi], e(r2))
				* Controlled Regressions
				reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
				matrix coeff_`y' = (coeff_`y' \ _b[north_avi],  _se[north_avi], e(r2))
				
				local r2= 1.3*e(r2)
				
				*Delta needed to zero out effect
				psacalc delta north_avi, rmax(`r2')  mcontrol(dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3) model(reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust)
				matrix coeff_`y' = (coeff_`y' \ r(delta), 1, 1)

				*Beta assuming delta of 1 and 1.3R Rmax
				psacalc beta north_avi, rmax(`r2') mcontrol(dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3) model(reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust)
				matrix coeff_`y' = (coeff_`y' \ r(beta), 1, 1)
			
		*5 Degree Restricted Sample	
				keep if dist_avi1>=-5 & dist_avi1<=5	
				*Baseline Regressions
				reg `y' north_avi dist_avi1 north_dist1 [w=population], robust
				matrix coeff_`y' = (coeff_`y' \ _b[north_avi],  _se[north_avi], e(r2))

				*Controlled Regressions
				reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population], robust
				matrix coeff_`y' = (coeff_`y' \ _b[north_avi],  _se[north_avi], e(r2))
				
				local r2= 1.3*e(r2)
				
				*Delta needed to zero out effect
				psacalc delta north_avi, rmax(`r2') mcontrol(dist_avi1 north_dist1) model(reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population], robust  )
				matrix coeff_`y' = (coeff_`y' \ r(delta), 1, 1)

				*Beta assuming delta of 1 and 1.3R Rmax
				psacalc beta north_avi, rmax(`r2') mcontrol(dist_avi1 north_dist1) model(reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population], robust )
				matrix coeff_`y' = (coeff_`y' \ r(beta), 1, 1)
				
		matsave coeff_`y', replace path("$path/Do_Files/Results") saving
		
		restore
	}	
	*Exporting to Excel
	use "$path/Do_Files/Results/coeff_r03_pm10", clear
	export excel using "$path/Do_Files/Results/Table", sheet("coeff_r03_pm10", replace)

	use "$path/Do_Files/Results/coeff_ex", clear
	export excel using "$path/Do_Files/Results/Table", sheet("coeff_ex", replace)

	use "$path/Do_Files/Results/coeff_l_ajdr4", clear
	export excel using "$path/Do_Files/Results/Table", sheet("coeff_l_ajdr4", replace)

	use "$path/Do_Files/Results/coeff_l_ajdr10", clear	
	export excel using "$path/Do_Files/Results/Table", sheet("coeff_l_ajdr10", replace)
