*======================================================================*
* TABLE S3: Regression discontinuity estimates of the impact of the
* Huai River by cause of death	
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"

//CODE
use "`IN'/RD_data_merged.dta", clear

* Leaves us with 154 observations out of 161.
keep if r03_pm10 != .

* Controls
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  

* Getting Predicted Life Expectancy
reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals

cap erase "`OUT'/TableS3_poly_RD.txt"
cap erase "`OUT'/TableS3_poly_RD.xml"
cap erase "`OUT'/TableS3_linear_RD.txt"
cap erase "`OUT'/TableS3_linear_RD.xml"

* LHS Variables
local outcome "l_ajdr1 l_ajdr4  l_ajdr5  l_ajdr7 l_ajdr13 l_ajdr19  l_ajdr10 l_ajdr6 l_ajdr11 l_ajdr22" 

** columns 1-4	
foreach y of local outcome {

	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/TableS3_poly_RD", excel dec(2) append

	 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/TableS3_poly_RD", excel dec(2) append


	reg `y' north_avi dist_avi1 north_dist1 [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/TableS3_linear_RD" , excel dec(2) append 
	
	
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/TableS3_linear_RD" , excel dec(2) append 

	}
	
** Columns 5-7
local kernelfn "tri epa uni"  
local bwmethod "IK CCT CV" 
	
foreach y of local outcome { 
	cap erase "`OUT'/TableS3_RD_`y'.txt" 
	cap erase "`OUT'/TableS3_RD_`y'.xml"
	} 	
	
* Authomatic bandwidth models: 
foreach y of local outcome { 
	foreach bvar of local bwmethod { 
		foreach kvar of local kernelfn { 
			rdrobust `y' lat_dist_avi_revised, kernel(`kvar') bwselect(`bvar') all 	
			outreg2 using "`OUT'/TableS3_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  ctitle(`dvar')  dec(2) append 
	 		}  	
		}
	} 			
	
* Manually choose bandwidth: 5 degrees
foreach y of local outcome { 
	foreach kvar of local kernelfn { 
		rdrobust `y' lat_dist_avi_revised, kernel(`kvar')  bwselect(IK) h(5) all 
		outreg2 using "`OUT'/TableS3_RD_`y'", excel addtext(Kernel Type, `e(kernel)', BW Type,`e(bwsel)', Observations, `e(N)')  	ctitle(`dvar')  dec(2) append 
		}
	} 

	
*** Output Table 2 ***
xmluse "`OUT'/TableS3_poly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_poly_RD", replace) 
	
xmluse "`OUT'/TableS3_linear_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_linear_RD", replace) 

xmluse "`OUT'/TableS3_RD_l_ajdr1.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr1", replace) 
	
xmluse "`OUT'/TableS3_RD_l_ajdr4.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr4", replace) 
	
xmluse "`OUT'/TableS3_RD_l_ajdr5.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr5", replace) 

xmluse "`OUT'/TableS3_RD_l_ajdr7.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr7", replace) 

xmluse "`OUT'/TableS3_RD_l_ajdr13.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr13", replace) 

xmluse "`OUT'/TableS3_RD_l_ajdr19.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr19", replace) 
	
xmluse "`OUT'/TableS3_RD_l_ajdr10.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr10", replace) 

xmluse "`OUT'/TableS3_RD_l_ajdr6.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr6", replace) 
	
xmluse "`OUT'/TableS3_RD_l_ajdr11.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr11", replace) 
	
xmluse "`OUT'/TableS3_RD_l_ajdr22.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS3", sheet("TableS3_RD_l_ajdr22", replace) 


* Clean up Output folder for less clutter
cap erase "`OUT'/TableS3_poly_RD.txt"
cap erase "`OUT'/TableS3_poly_RD.xml"
cap erase "`OUT'/TableS3_linear_RD.txt"
cap erase "`OUT'/TableS3_linear_RD.xml"
foreach y of local outcome { 
	cap erase "`OUT'/TableS3_RD_`y'.txt" 
	cap erase "`OUT'/TableS3_RD_`y'.xml"
	} 	
