*======================================================================*
* TABLE S4: Health-related behavioral patterns by sex, south and north
* of the Huai River	
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local OUT $root/Do_Files/Results/
local IN $root/Data_Files/

//CODE

*male
use "`IN'/RD_data_04_12_new_v4_male_S16.dta", clear

* Leaves us with 154 observations out of 161.
keep if r03_pm10 != .
cap erase "`OUT'/S4_simple_diff_male.txt"
cap erase "`OUT'/S4_simple_diff_male.xml"
cap erase "`OUT'/S4_poly_diff_male.txt"
cap erase "`OUT'/S4_poly_diff_male.xml"
cap erase "`OUT'/S4_local_diff_male.txt"
cap erase "`OUT'/S4_local_diff_male.xml"

* Columns 1 and 2 
local outcome "smkexp bdrk redmeat inspa hbp"
sum `outcome' [w=population] if north_avi == 1, sep(0)
sum `outcome' [w=population] if north_avi == 0, sep(0)

* Columns 3: simple difference
foreach y of local outcome { 
	reg `y' north_avi [w=population], robust
	outreg2 using "`OUT'/S4_simple_diff_male", excel stats(coef se pval) ctitle(`y') dec(4) append 
	}

* Columns 4: 3rd order polynomial adjusted difference
foreach y of local outcome { 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/S4_poly_diff_male", excel stats(coef se pval) dec(4) append
	}

* Columns 5: local linear regression adjusted difference
foreach y of local outcome {
	rdrobust `y' lat_dist_avi_revised,  bwselect(IK) all
	outreg2 using "`OUT'/S4_local_diff_male", excel ctitle(`y') addstat(Robust Std. Err., e(se_rb), Robust p-value, e(pv_rb)) dec(4) append 
}


*** female ***
use "`IN'/RD_data_04_12_new_v4_female_S16", clear
mdesc pm10 r03_pm10
keep if r03_pm10 != .

cap erase "`OUT'/S4_simple_diff_female.txt"
cap erase "`OUT'/S4_simple_diff_female.xml"
cap erase "`OUT'/S4_poly_diff_female.txt"
cap erase "`OUT'/S4_poly_diff_female.xml"
cap erase "`OUT'/S4_local_diff_female.txt"
cap erase "`OUT'/S4_local_diff_female.xml"

* Columns 1 and 2 
local outcome "smkexp bdrk redmeat inspa hbp"
sum `outcome' [w=population] if north_avi == 1, sep(0)
sum `outcome' [w=population] if north_avi == 0, sep(0)

* Columns 3: simple difference
foreach y of local outcome { 
	reg `y' north_avi [w=population], robust
	outreg2 using "`OUT'/S4_simple_diff_female", excel stats(coef se pval) ctitle(`y') dec(4) append 
	}

* Columns 4: 3rd order polynomial adjusted difference
foreach y of local outcome { 
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 [w=population], robust
	outreg2 using "`OUT'/S4_poly_diff_female", excel stats(coef se pval) dec(4) append
	}

* Columns 5: local linear regression adjusted difference
foreach y of local outcome {
	rdrobust `y' lat_dist_avi_revised,  bwselect(IK) all
	outreg2 using "`OUT'/S4_local_diff_female", excel ctitle(`y') addstat(Robust Std. Err., e(se_rb), Robust p-value, e(pv_rb)) dec(4) append 
	}


* Output: Table S4
xmluse "`OUT'/S4_simple_diff_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS4", sheet("S4_simple_diff_male", replace) 

xmluse "`OUT'/S4_poly_diff_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS4", sheet("S4_poly_diff_male", replace) 

xmluse "`OUT'/S4_local_diff_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS4", sheet("S4_local_diff_male", replace) 

xmluse "`OUT'/S4_simple_diff_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS4", sheet("S4_simple_diff_female", replace) 

xmluse "`OUT'/S4_poly_diff_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS4", sheet("S4_poly_diff_female", replace) 

xmluse "`OUT'/S4_local_diff_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS4", sheet("S4_local_diff_female", replace) 

* Clear Clutter
cap erase "`OUT'/S4_simple_diff_male.txt"
cap erase "`OUT'/S4_simple_diff_male.xml"
cap erase "`OUT'/S4_poly_diff_male.txt"
cap erase "`OUT'/S4_poly_diff_male.xml"
cap erase "`OUT'/S4_local_diff_male.txt"
cap erase "`OUT'/S4_local_diff_male.xml"
cap erase "`OUT'/S4_simple_diff_female.txt"
cap erase "`OUT'/S4_simple_diff_female.xml"
cap erase "`OUT'/S4_poly_diff_female.txt"
cap erase "`OUT'/S4_poly_diff_female.xml"
cap erase "`OUT'/S4_local_diff_female.txt"
cap erase "`OUT'/S4_local_diff_female.xml"
