*======================================================================*
* TABLE S5: Regression discontinuity estimates of the impact of PM10
* on health outcomes by sex
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"

//CODE

* male

* erasing existing files
cap erase "`OUT'/S5_poly_RD_male.xml"
cap erase "`OUT'/S5_poly_RD_male.txt"
cap erase "`OUT'/S5_linear_RD_male.xml"
cap erase "`OUT'/S5_linear_RD_male.txt"
cap erase "`OUT'/S5_poly_IVRD_male.xml"
cap erase "`OUT'/S5_poly_IVRD_male.txt"
cap erase "`OUT'/S5_linear_IVRD_male.xml"
cap erase "`OUT'/S5_linear_IVRD_male.txt"
cap erase "`OUT'/S5_local_RD_male.xml"
cap erase "`OUT'/S5_local_RD_male.txt"
cap erase "`OUT'/S5_local_FzRD_male.xml"
cap erase "`OUT'/S5_local_FzRD_male.txt"

use "`IN'/RD_data_04_12_new_v4_male_S16.dta", clear
* Leaves us with 154 observations out of 161.
keep if r03_pm10 != .

* To get estimates for every 10 microgram increase in pm10 concentration
replace r03_pm10 = r03_pm10/10

* Controls & Outcomes
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  
local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11" 


* Getting Predicted Life Expectancy
reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals
 

foreach y of local outcome  {
	local d=2
	if `y'==ex{
		local d = 1
	}
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/S5_poly_RD_male", excel dec(`d') append
	
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S5_linear_RD_male", excel dec(`d') append 
	
	rdrobust `y' lat_dist_avi_revised,  bwselect(IK) all
	outreg2 using "`OUT'/S5_local_RD_male", excel ctitle(`y')  dec(`d') append 
	
	local d=2
	
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S5_poly_IVRD_male", excel dec(`d')  adds(Chi-squared, e(chi2)) append
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5
	outreg2 using "`OUT'/S5_linear_IVRD_male", excel dec(`d')  adds(Chi-squared, e(chi2)) append

	rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10)  bwselect(IK) all 
	outreg2 using "`OUT'/S5_local_FzRD_male", excel ctitle(`y') dec(`d') append 

	}



* female

* erasing existing files
cap erase "`OUT'/S5_poly_RD_female.xml"
cap erase "`OUT'/S5_poly_RD_female.txt"
cap erase "`OUT'/S5_linear_RD_female.xml"
cap erase "`OUT'/S5_linear_RD_female.txt"
cap erase "`OUT'/S5_poly_IVRD_female.xml"
cap erase "`OUT'/S5_poly_IVRD_female.txt"
cap erase "`OUT'/S5_linear_IVRD_female.xml"
cap erase "`OUT'/S5_linear_IVRD_female.txt"
cap erase "`OUT'/S5_local_RD_female.xml"
cap erase "`OUT'/S5_local_RD_female.txt"
cap erase "`OUT'/S5_local_FzRD_female.xml"
cap erase "`OUT'/S5_local_FzRD_female.txt"




use "`IN'/RD_data_04_12_new_v4_female_S16", clear
* Leaves us with 154 observations out of 161.
keep if r03_pm10 != .

* To get estimates for every 10 microgram increase in pm10 concentration
replace r03_pm10=r03_pm10/10 

* Controls & Outcomes
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  
local outcome "ex ex5 ex60 l_ajdr4 resid_ex l_ajdr10 l_ajdr11"

* Getting Predicted Life Expectancy
reg ex `OLS_var' [w=population], robust
predict pred_ex
predict resid_ex, residuals



foreach y of local outcome {
	local d=2
	if `y'==ex{
		local d = 1
	}
	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/S5_poly_RD_female", excel dec(`d') append
	reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
	outreg2 using "`OUT'/S5_linear_RD_female", excel dec(`d') append 

	rdrobust `y' lat_dist_avi_revised,  bwselect(IK) all
	outreg2 using "`OUT'/S5_local_RD_female", excel ctitle(`y')  dec(`d') append 

	local d=2
	
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S5_poly_IVRD_female", excel dec(`d')  adds(Chi-squared, e(chi2)) append
	ivregress 2sls `y' dist_avi1 north_dist1 `OLS_var' (r03_pm10 = north_avi) [w=population] if dist_avi1>=-5 & dist_avi1<=5
	outreg2 using "`OUT'/S5_linear_IVRD_female", excel dec(`d')  adds(Chi-squared, e(chi2)) append

	rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10)  bwselect(IK) all 
	outreg2 using "`OUT'/S5_local_FzRD_female", excel  ctitle(`y')  dec(`d') append 

	}




** Output: Table S5 **

xmluse "`OUT'/S5_poly_RD_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_poly_RD_male", replace) 

xmluse "`OUT'/S5_linear_RD_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_linear_RD_male", replace) 

xmluse "`OUT'/S5_poly_IVRD_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_poly_IVRD_male", replace) 

xmluse "`OUT'/S5_linear_IVRD_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_linear_IVRD_male", replace) 

xmluse "`OUT'/S5_local_RD_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_local_RD_male", replace) 

xmluse "`OUT'/S5_local_FzRD_male.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_local_FzRD_male", replace) 

xmluse "`OUT'/S5_poly_RD_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_poly_RD_female", replace) 

xmluse "`OUT'/S5_linear_RD_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_linear_RD_female", replace) 

xmluse "`OUT'/S5_poly_IVRD_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_poly_IVRD_female", replace) 

xmluse "`OUT'/S5_linear_IVRD_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_linear_IVRD_female", replace) 

xmluse "`OUT'/S5_local_RD_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_local_RD_female", replace) 

xmluse "`OUT'/S5_local_FzRD_female.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS5", sheet("S5_local_FzRD_female", replace) 


* Reduce Clutter
cap erase "`OUT'/S5_poly_RD_male.xml"
cap erase "`OUT'/S5_poly_RD_male.txt"
cap erase "`OUT'/S5_linear_RD_male.xml"
cap erase "`OUT'/S5_linear_RD_male.txt"
cap erase "`OUT'/S5_poly_IVRD_male.xml"
cap erase "`OUT'/S5_poly_IVRD_male.txt"
cap erase "`OUT'/S5_linear_IVRD_male.xml"
cap erase "`OUT'/S5_linear_IVRD_male.txt"
cap erase "`OUT'/S5_local_RD_male.xml"
cap erase "`OUT'/S5_local_RD_male.txt"
cap erase "`OUT'/S5_local_FzRD_male.xml"
cap erase "`OUT'/S5_local_FzRD_male.txt"
cap erase "`OUT'/S5_poly_RD_female.xml"
cap erase "`OUT'/S5_poly_RD_female.txt"
cap erase "`OUT'/S5_linear_RD_female.xml"
cap erase "`OUT'/S5_linear_RD_female.txt"
cap erase "`OUT'/S5_poly_IVRD_female.xml"
cap erase "`OUT'/S5_poly_IVRD_female.txt"
cap erase "`OUT'/S5_linear_IVRD_female.xml"
cap erase "`OUT'/S5_linear_IVRD_female.txt"
cap erase "`OUT'/S5_local_RD_female.xml"
cap erase "`OUT'/S5_local_RD_female.txt"
cap erase "`OUT'/S5_local_FzRD_female.xml"
cap erase "`OUT'/S5_local_FzRD_female.txt"
