*======================================================================*
* TABLE S6: The Huai River policy and the impact of PM10 on 
* cardiorespiratory mortality throughout the life cycle
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"


//CODE
use "`IN'/RD_data_merged.dta", clear
* leaves 154 obs
keep if r03_pm10 != .
* To measure for every 10 microgram change in pm10
replace r03_pm10=r03_pm10/10 

*remove existing files
cap erase "`OUT'/s6_poly_age_group.xml"
cap erase "`OUT'/S6_poly_age_group.txt"
cap erase "`OUT'/S6_RD_age_group.xml"
cap erase "`OUT'/S6_RD_age_group.txt"
cap erase "`OUT'/S6_IVpoly_age_group.xml"
cap erase "`OUT'/S6_IVpoly_age_group.txt"
cap erase "`OUT'/S6_FzRD_age_group.xml"
cap erase "`OUT'/S6_FzRD_age_group.txt"

*Outcomes & Controls
local outcome "l_dr4 l_dr4_1 l_dr4_5 l_dr4_10 l_dr4_15 l_dr4_20 l_dr4_25 l_dr4_30 l_dr4_35 l_dr4_40 l_dr4_45 l_dr4_50 l_dr4_55 l_dr4_60 l_dr4_65 l_dr4_70 l_dr4_75 l_dr4_80 l_dr4_85 l_dr10 l_dr10_1 l_dr10_5 l_dr10_10 l_dr10_15 l_dr10_20 l_dr10_25 l_dr10_30 l_dr10_35 l_dr10_40 l_dr10_45 l_dr10_50 l_dr10_55 l_dr10_60 l_dr10_65 l_dr10_70 l_dr10_75 l_dr10_80 l_dr10_85"
local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  

foreach y of local outcome {  

	reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
	outreg2 using "`OUT'/S6_poly_age_group", excel dec(2) ctitle(`y') append
	ivregress 2sls `y' dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' (r03_pm10 = north_avi) [w=population]
	outreg2 using "`OUT'/S6_IVpoly_age_group", excel dec(2) ctitle(`y') append

	}

foreach y of local outcome {

	rdrobust `y' lat_dist_avi_revised,  bwselect(IK) all
	outreg2 using "`OUT'/S6_RD_age_group", excel ctitle(`y')  dec(2) append 
	rdrobust `y' lat_dist_avi_revised, fuzzy(r03_pm10)  bwselect(IK) all 
	outreg2 using "`OUT'/S6_FzRD_age_group", excel  ctitle(`y')  dec(2) append 
	
	}

** Output: Table S6 ** 
xmluse "`OUT'/S6_poly_age_group.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/tableS6", sheet("S6_poly_age_group", replace) 

xmluse "`OUT'/S6_RD_age_group.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/tableS6", sheet("S6_RD_age_group", replace) 

xmluse "`OUT'/S6_IVpoly_age_group.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/tableS6", sheet("S6_IVpoly_age_group", replace) 

xmluse "`OUT'/S6_FzRD_age_group.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/tableS6", sheet("S6_FzRD_age_group", replace) 

*remove clutter
cap erase "`OUT'/S6_poly_age_group.xml"
cap erase "`OUT'/S6_poly_age_group.txt"
cap erase "`OUT'/S6_RD_age_group.xml"
cap erase "`OUT'/S6_RD_age_group.txt"
cap erase "`OUT'/S6_IVpoly_age_group.xml"
cap erase "`OUT'/S6_IVpoly_age_group.txt"
cap erase "`OUT'/S6_FzRD_age_group.xml"
cap erase "`OUT'/S6_FzRD_age_group.txt"
