*======================================================================*
* TABLE S9: Robustness checks of choice of functional form for latitude
*======================================================================*

//Settings
clear
set type double
set more off 
tempfile t1 t2 t3 t4 t5 

//DIRECTORIES
global root /Users/`c(username)'/Desktop/Huai_River_Replication_Files
local folder "$root"
local OUT "`folder'/Do_Files/Results/"
local IN "`folder'/Data_Files/"
local OUT_A "`OUT'/AIC/"

//Code

cap erase "`OUT'/S9_poly_RD.xml"
cap erase "`OUT'/S9_poly_RD.txt"
cap erase "`OUT'/S9_IVpoly_RD.xml"
cap erase "`OUT'/S9_IVpoly_RD.txt"


use "`IN'/RD_data_merged", clear
keep if r03_pm10 != .


local OLS_var "smkexp bdrk redmeat inspa r04_heating_degrees r04_cooling_degrees rainfall pcincome v5_yrsed minoshare dist_dum100 medservice r2003_Level"  


local outcome "r03_pm10 ex l_ajdr4 l_ajdr10" 

foreach y of local outcome  {

* no interaction 
quietly reg `y' north_avi dist_avi1 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic1

quietly reg `y' north_avi dist_avi1 dist_avi2 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic2

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic3

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 dist_avi4 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic4

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 dist_avi4 dist_avi5 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic5

* with interaction
quietly reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic6

quietly reg `y' north_avi dist_avi1 dist_avi2 north_dist1 north_dist2 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic7

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic8

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 dist_avi4 north_dist1 north_dist2 north_dist3 north_dist4 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic9

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 dist_avi4 dist_avi5 north_dist1 north_dist2 north_dist3 north_dist4 north_dist5 `OLS_var' [w=population], robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic10

* within 5 degree of the Huai River 
quietly reg `y' north_avi dist_avi1 north_dist1 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic11

quietly reg `y' north_avi dist_avi1 dist_avi2 north_dist1 north_dist2 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic12

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic13

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 dist_avi4 north_dist1 north_dist2 north_dist3 north_dist4 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic14

quietly reg `y' north_avi dist_avi1 dist_avi2 dist_avi3 dist_avi4 dist_avi5 north_dist1 north_dist2 north_dist3 north_dist4 north_dist5 `OLS_var' [w=population] if dist_avi1>=-5 & dist_avi1<=5 , robust
outreg2 using "`OUT'/S9_poly_RD", excel ctitle(`y') dec(2) append
estimates store aic15

estimates stats aic*
matrix define aicout=r(S) 
xsvmat aicout, names(matcol) saving("`OUT_A'/TableS9_AIC_`y'.dta", replace) 
matrix aicT=aicout' 
putexcel set "`OUT'/aicout", sheet("`y'", replace) modify
putexcel A1=matrix(aicT), colnames   
}



replace r03_pm10=r03_pm10/10 
local outcome "ex l_ajdr4 l_ajdr10" 
foreach y of local outcome  {

* IV no interaction 

quietly ivregress 2sls `y'  dist_avi1 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic1

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic2

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 dist_avi3 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic3

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 dist_avi3 dist_avi4 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic4

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 dist_avi3 dist_avi4 dist_avi5 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic5

* IV with interaction
quietly ivregress 2sls `y'  dist_avi1 north_dist1 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic6

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 north_dist1 north_dist2 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic7

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 dist_avi3 north_dist1 north_dist2 north_dist3 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic8

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 dist_avi3 dist_avi4 north_dist1 north_dist2 north_dist3 north_dist4 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic9

quietly ivregress 2sls `y'  dist_avi1 dist_avi2 dist_avi3 dist_avi4 dist_avi5 north_dist1 north_dist2 north_dist3 north_dist4 north_dist5 `OLS_var'  (r03_pm10 = north_avi) [w=population], robust
outreg2 using "`OUT'/S9_IVpoly_RD", excel ctitle(`y') dec(2) append
estimates store aic10


estimates stats aic*

matrix define aicout=r(S) 
xsvmat aicout, names(matcol) saving("`OUT_A'/TableS9_AIC_IV_`y'.dta", replace) 
matrix aicT=aicout' 
putexcel set "`OUT'/aicout", sheet("`y'_IV", replace) modify
putexcel A1=matrix(aicT), colnames
}



** output Table S9 ** 
xmluse "`OUT'/S9_poly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS9", sheet("S9_poly_RD", replace)

xmluse "`OUT'/S9_IVpoly_RD.xml", doctype(excel) sheet(Sheet1) cells(A2:FZ100) allstring missing nocompress clear 
export excel using "`OUT'/TableS9", sheet("S9_IVpoly_RD", replace)


local outcome "r03_pm10 ex l_ajdr4 l_ajdr10" 
foreach y of local outcome  {
	import excel using "`OUT'/aicout.xlsx" , sheet("`y'") allstring firstrow clear 
	foreach v of varlist _all {
		destring `v', replace force 
	} 
	export excel using "`OUT'/TableS9", sheet("poly_AIC_`y'", replace)
}

local outcome "ex l_ajdr4 l_ajdr10" 
foreach y of local outcome  {
	import excel using "`OUT'/aicout.xlsx", sheet("`y'_IV") allstring firstrow clear 
	foreach v of varlist _all {
		destring `v', replace force 
	} 
	export excel using "`OUT'/TableS9", sheet("IVpoly_AIC_`y'", replace)
}

cap erase "`OUT'/S9_poly_RD.xml"
cap erase "`OUT'/S9_poly_RD.txt"
cap erase "`OUT'/S9_IVpoly_RD.xml"
cap erase "`OUT'/S9_IVpoly_RD.txt"
